/* Grid desktop MS / No grid support */
.woocommerce div.product .woocommerce-tabs ul.tabs.wc-tabs li a, .woocommerce nav.woocommerce-pagination ul li a, .woocommerce ul.products[class*="columns-"] li.product-category.product a img {
  -webkit-transition: all 0.3s ease;
  -moz-transition: all 0.3s ease;
  -ms-transition: all 0.3s ease;
  -o-transition: all 0.3s ease;
  transition: all 0.3s ease;
}

.woocommerce .single-product div.product form.cart .button, .woocommerce #respond input#submit, .woocommerce a.button, .woocommerce button.button, .woocommerce input.button, .woocommerce #respond input#submit.alt, .woocommerce a.button.alt, .woocommerce button.button.alt, .woocommerce input.button.alt, .woocommerce input.button:disabled, .woocommerce input.button[disabled]:disabled, #add_payment_method .wc-proceed-to-checkout a.checkout-button,
.woocommerce-cart .wc-proceed-to-checkout a.checkout-button,
.woocommerce-checkout .wc-proceed-to-checkout a.checkout-button, .added_to_cart.wc-forward {
  -webkit-transition: background-color 0.2s cubic-bezier(0.4, 0, 0.2, 1), -webkit-box-shadow 0.2s cubic-bezier(0.4, 0, 1, 1);
  transition: background-color 0.2s cubic-bezier(0.4, 0, 0.2, 1), -webkit-box-shadow 0.2s cubic-bezier(0.4, 0, 1, 1);
  transition: box-shadow 0.2s cubic-bezier(0.4, 0, 1, 1), background-color 0.2s cubic-bezier(0.4, 0, 0.2, 1);
  transition: box-shadow 0.2s cubic-bezier(0.4, 0, 1, 1), background-color 0.2s cubic-bezier(0.4, 0, 0.2, 1), -webkit-box-shadow 0.2s cubic-bezier(0.4, 0, 1, 1);
}

.woocommerce div.product form.cart .variations select, .woocommerce .woocommerce-ordering select, .woocommerce-cart .shop_table .actions .coupon .input-text, .woocommerce-checkout #customer_details select,
.woocommerce-checkout #order_review select,
.woocommerce-checkout .woocomerce-form select, .woocommerce.single-product .page-header .container .cart-contents-content.btn-white.btn-simple:focus, .woocommerce.single-product .page-header .container .cart-contents-content.btn-white.btn-simple:hover {
  -webkit-box-shadow: none;
  -moz-box-shadow: none;
  box-shadow: none;
}

.woocommerce div.product form.cart .variations select, .woocommerce .woocommerce-ordering select, .woocommerce-cart .shop_table .actions .coupon .input-text, .woocommerce-checkout #customer_details select,
.woocommerce-checkout #order_review select,
.woocommerce-checkout .woocomerce-form select {
  background-image: -webkit-gradient(linear, right top, right bottom, from(#9c27b0), to(#9c27b0)), -webkit-gradient(linear, right top, right bottom, from(#d2d2d2), to(#d2d2d2));
  background-image: -webkit-linear-gradient(#9c27b0, #9c27b0), -webkit-linear-gradient(#d2d2d2, #d2d2d2);
  background-image: linear-gradient(#9c27b0, #9c27b0), linear-gradient(#d2d2d2, #d2d2d2);
  float: none;
  border: 0;
  border-radius: 0;
  background-color: transparent;
  background-repeat: no-repeat;
  background-position: center bottom, center -webkit-calc(100% - 1px);
  background-position: center bottom, center calc(100% - 1px);
  background-size: 0 2px, 100% 1px;
  font-weight: 400;
  -webkit-transition: background 0s ease-out;
  transition: background 0s ease-out;
}

/*--------------------------------------------------------------
# Woocommerce Integration
--------------------------------------------------------------*/
/*--------------------------------------------------------------
## Generic
--------------------------------------------------------------*/
.woocommerce.archive .main {
  background-color: #f0f0f0;
}
.woocommerce.archive .blog-post {
  padding-right: 0;
  padding-left: 0;
}
.woocommerce.archive .blog-post .products {
  margin-right: -15px;
  margin-left: -15px;
}
.woocommerce.archive .blog-post .section {
  padding: 0 15px 70px;
}
.woocommerce.single-product.header-layout-classic-blog .blog-post {
  background: #fff;
}
.woocommerce.single-product.header-layout-classic-blog .blog-post .col-md-12 > div[id^=product].product {
  margin: 0;
  box-shadow: none;
  -webkit-box-shadow: none;
}
.woocommerce.single-product .main.main-raised {
  margin: 0;
  border-radius: 0;
  -webkit-box-shadow: 0;
  box-shadow: 0;
}
.woocommerce.single-product .blog-post {
  background-color: #f0f0f0;
}
.woocommerce.single-product .blog-post .col-md-12 > div[id^=product].product {
  margin: -315px 0 0;
  padding: 40px;
  border-radius: 6px;
  background: #fff;
  -webkit-box-shadow: 0 16px 24px 2px rgba(0, 0, 0, 0.14), 0 6px 30px 5px rgba(0, 0, 0, 0.12), 0 8px 10px -5px rgba(0, 0, 0, 0.2);
  box-shadow: 0 16px 24px 2px rgba(0, 0, 0, 0.14), 0 6px 30px 5px rgba(0, 0, 0, 0.12), 0 8px 10px -5px rgba(0, 0, 0, 0.2);
}
.woocommerce.single-product .blog-post .col-md-12 > div[id^=product].product:after {
  content: "";
  display: table;
  clear: both;
}
.woocommerce.single-product .section {
  padding: 0 0 70px;
}
.woocommerce.single-product .page-header {
  z-index: 0;
  min-height: 575px;
  height: auto;
  background-position: top center;
}
.woocommerce.single-product .page-header .container .cart-contents-content {
  left: 15px;
  position: relative;
  bottom: -10px;
}
.woocommerce.single-product .page-header .container .cart-contents-content.btn-white {
  box-shadow: 0 2px 2px 0 rgba(153, 153, 153, 0.14), 0 3px 1px -2px rgba(153, 153, 153, 0.2), 0 1px 5px 0 rgba(153, 153, 153, 0.12);
  color: #999999;
  background-color: #fff;
}
.woocommerce.single-product .page-header .container .cart-contents-content.btn-white.btn-white:focus, .woocommerce.single-product .page-header .container .cart-contents-content.btn-white.btn-white:hover {
  color: #fff;
  background-color: rgba(153, 153, 153, 0.6);
}
.woocommerce.single-product .page-header .container .cart-contents-content.btn-white.btn-white:focus.btn-simple, .woocommerce.single-product .page-header .container .cart-contents-content.btn-white.btn-white:hover.btn-simple {
  color: #fff;
  background: transparent;
}
.woocommerce.single-product .product_title {
  color: #3C4858;
  font-family: "Roboto Slab", "Times New Roman", serif;
}
.woocommerce.single-product .summary .price,
.woocommerce.single-product .woocommerce-variation-price .price {
  display: block;
  color: #3C4858;
  font-family: "Roboto", "Helvetica", "Arial", sans-serif;
}
.woocommerce.single-product .summary .price {
  margin: 10px 0 25px;
}
.woocommerce.single-product .summary .price.price-unit {
  margin: -20px 0 25px;
}
.woocommerce.single-product .woocommerce-variation-price .price {
  margin: 0 0 25px;
}
.woocommerce.single-product div.product form.cart table.variations {
  margin-bottom: 0;
}
.woocommerce.single-product div.product form.cart table.variations td.label label {
  margin-bottom: 0;
}
.woocommerce.single-product div.product form.cart table.variations td.value {
  padding-top: 0;
  position: relative;
}
.woocommerce.single-product div.product form.cart table.variations td.value:before {
  content: '\f0d7';
  font-family: "Font Awesome 5 Free";
  font-weight: 900;
  position: absolute;
  top: 7px;
  left: 10px;
  display: inline-block;
  pointer-events: none;
}
.woocommerce.single-product .upsells {
  margin-top: 60px;
  padding-top: 0;
}
.woocommerce.single-product .upsells h2 {
  margin: 0 0 60px;
  text-align: center;
}
.woocommerce.single-product .related ul.products {
  margin: 0 -15px;
}
.woocommerce .page-header .container {
  position: relative;
}
.woocommerce .page-header .container .cart-contents-content {
  z-index: 1;
  left: 15px;
  position: absolute;
  bottom: 30px;
}
.woocommerce .page-header .container .cart-contents-content i {
  vertical-align: -2px;
  margin-left: 5px;
}
.woocommerce div.product form.cart .reset_variations {
  float: left;
  margin-top: 10px;
}
.woocommerce div.product form.cart .reset_variations:after {
  margin-right: 5px;
  font-family: "Font Awesome 5 Free";
  font-weight: 900;
  content: "\f00d";
}
.woocommerce div.product form.cart input {
  margin-left: 10px;
  border: none;
  border-bottom: 1px solid #ccc;
}
.woocommerce div.product form.cart .button:after {
  background-image: url(data:image/svg+xml;base64,PHN2ZyBhcmlhLWhpZGRlbj0idHJ1ZSIgZm9jdXNhYmxlPSJmYWxzZSIgZGF0YS1wcmVmaXg9ImZhcyIgZGF0YS1pY29uPSJzaG9wcGluZy1jYXJ0IiByb2xlPSJpbWciIHhtbG5zPSJodHRwOi8vd3d3LnczLm9yZy8yMDAwL3N2ZyIgdmlld0JveD0iMCAwIDU3NiA1MTIiIGNsYXNzPSJzdmctaW5saW5lLS1mYSBmYS1zaG9wcGluZy1jYXJ0IGZhLXctMTggZmEtbGciPjxwYXRoIGZpbGw9IiNmZmZmZmYiIGQ9Ik01MjguMTIgMzAxLjMxOWw0Ny4yNzMtMjA4QzU3OC44MDYgNzguMzAxIDU2Ny4zOTEgNjQgNTUxLjk5IDY0SDE1OS4yMDhsLTkuMTY2LTQ0LjgxQzE0Ny43NTggOC4wMjEgMTM3LjkzIDAgMTI2LjUyOSAwSDI0QzEwLjc0NSAwIDAgMTAuNzQ1IDAgMjR2MTZjMCAxMy4yNTUgMTAuNzQ1IDI0IDI0IDI0aDY5Ljg4M2w3MC4yNDggMzQzLjQzNUMxNDcuMzI1IDQxNy4xIDEzNiA0MzUuMjIyIDEzNiA0NTZjMCAzMC45MjggMjUuMDcyIDU2IDU2IDU2czU2LTI1LjA3MiA1Ni01NmMwLTE1LjY3NC02LjQ0Ny0yOS44MzUtMTYuODI0LTQwaDIwOS42NDdDNDMwLjQ0NyA0MjYuMTY1IDQyNCA0NDAuMzI2IDQyNCA0NTZjMCAzMC45MjggMjUuMDcyIDU2IDU2IDU2czU2LTI1LjA3MiA1Ni01NmMwLTIyLjE3Mi0xMi44ODgtNDEuMzMyLTMxLjU3OS01MC40MDVsNS41MTctMjQuMjc2YzMuNDEzLTE1LjAxOC04LjAwMi0yOS4zMTktMjMuNDAzLTI5LjMxOUgyMTguMTE3bC02LjU0NS0zMmgyOTMuMTQ1YzExLjIwNiAwIDIwLjkyLTcuNzU0IDIzLjQwMy0xOC42ODF6IiBjbGFzcz0iIj48L3BhdGg+PC9zdmc+);
  display: inline-block;
  width: 13.5px;
  height: 13px;
  background-size: 13px;
  background-repeat: no-repeat;
  content: '';
  margin-right: 10px;
  vertical-align: middle;
}
.woocommerce div.product .woocommerce-tabs ul.tabs {
  margin-bottom: 60px;
  padding: 0;
}
.woocommerce div.product .woocommerce-tabs ul.tabs.wc-tabs {
  overflow: visible;
}
.woocommerce div.product .woocommerce-tabs ul.tabs.wc-tabs li {
  background: none;
}
.woocommerce div.product .woocommerce-tabs ul.tabs li {
  padding: 0 0 0 30px;
  margin: 0;
}
.woocommerce div.product .woocommerce-tabs ul.tabs li:after, .woocommerce div.product .woocommerce-tabs ul.tabs li:before {
  border: none;
  -webkit-box-shadow: none;
  box-shadow: none;
}
.woocommerce div.product .woocommerce-tabs ul.tabs.wc-tabs li {
  border: none;
}
.woocommerce div.product .woocommerce-tabs ul.tabs.wc-tabs li.active a {
  color: #e91e63;
  border-bottom: 2px solid #e91e63;
}
.woocommerce div.product .woocommerce-tabs ul.tabs.wc-tabs li a {
  border-bottom: 2px solid transparent;
  min-width: 100px;
  padding: 10px 15px;
  border-radius: 0;
  color: #555;
  text-align: center;
  text-transform: uppercase;
}
.woocommerce div.product .woocommerce-tabs ul.tabs.wc-tabs li a:hover {
  border-bottom: 2px solid #e91e63;
}
.woocommerce div.product .woocommerce-tabs ul.tabs:before {
  border: none;
}
.woocommerce div.product .woocommerce-tabs h2:first-child {
  display: none;
}
.woocommerce div.product .woocommerce-tabs .panel {
  box-shadow: none;
  margin-bottom: 0;
}
.woocommerce div.product p.stars a:before {
  color: #ff9800;
}
.woocommerce div.product form.cart .variations tr {
  display: inline-block;
  width: 48%;
  margin-bottom: 25px;
}
.woocommerce div.product form.cart .variations tr:nth-child(2n), .woocommerce div.product form.cart .variations tr td {
  float: left;
}
.woocommerce div.product form.cart .variations td.label {
  text-align: right;
}
.woocommerce div.product form.cart .variations td label {
  background: transparent;
  font-family: "Roboto", "Helvetica", "Arial", sans-serif;
  text-transform: none;
}
.woocommerce div.product form.cart .variations select {
  width: 100%;
  padding: 7px 0;
  border: none;
}
.woocommerce div.product form.cart .variations select:focus {
  background-size: 100% 2px, 100% 1px;
  -webkit-transition-duration: 0.3s;
  transition-duration: 0.3s;
}
.woocommerce div.product form.cart .variations td, .woocommerce div.product form.cart .variations th {
  width: 100%;
}
.woocommerce div.product div.images .flex-control-thumbs {
  margin-top: 10px;
}
.woocommerce div.product div.images .flex-control-thumbs li {
  margin-right: 2%;
  margin-bottom: 10px;
  width: 32%;
}
.woocommerce div.product div.images .flex-control-thumbs li:nth-child(3n+1), .woocommerce div.product div.images .flex-control-thumbs li:first-child {
  margin-right: 0;
}
.woocommerce.single-product .summary .price ins {
  text-decoration: none;
}
.woocommerce.single-product.header-layout-classic-blog .hestia-product-image-wrap {
  position: relative;
}
.woocommerce.single-product.header-layout-classic-blog .product[id^="product-"] span.onsale {
  top: -10px;
  right: -10px;
}
.woocommerce.single-product .product .images {
  margin-bottom: 60px;
  position: relative;
  width: 100%;
}
.woocommerce.single-product .product .hestia-product-image-wrap {
  float: right;
  width: 45%;
}
.woocommerce.single-product .product .summary {
  padding-right: 60px;
  margin-bottom: 60px;
  width: 55%;
}
.woocommerce.single-product .product span.onsale {
  position: absolute;
  top: -25px;
  right: -25px;
  left: auto;
  z-index: 2;
}
.woocommerce.single-product .product form.cart {
  margin: 60px 0 0;
  padding: 0;
}
.woocommerce.single-product .product .product_meta {
  margin-top: 10px;
}
.woocommerce.single-product .product .product_meta .posted_in, .woocommerce.single-product .product .product_meta .tagged_as {
  display: block;
}
.woocommerce.single-product .product .woocommerce-product-rating {
  margin-bottom: 0;
}
.woocommerce.single-product .woocommerce-breadcrumb {
  margin: 0 0 23px;
}
.woocommerce span.onsale {
  top: -25px;
  right: -25px;
  border-radius: 3px;
  text-transform: uppercase;
  padding: 0 10px;
  z-index: 2;
}
.woocommerce #respond input#submit.added:after, .woocommerce a.button.added:after, .woocommerce button.button.added:after, .woocommerce input.button.added:after {
  color: #4caf50;
}
.woocommerce .single-product div.product form.cart .button, .woocommerce #respond input#submit, .woocommerce a.button, .woocommerce button.button, .woocommerce input.button, .woocommerce #respond input#submit.alt, .woocommerce a.button.alt, .woocommerce button.button.alt {
  padding: 12px 30px;
  border-radius: 3px;
  color: #fff;
  background-color: #9c27b0;
  font-family: "Roboto", "Helvetica", "Arial", sans-serif;
  text-transform: uppercase;
}
.woocommerce input.button.alt {
  padding: 12px 30px;
  border-radius: 3px;
  color: #fff;
  background-color: #9c27b0;
  font-family: "Roboto", "Helvetica", "Arial", sans-serif;
  text-transform: uppercase;
}
.woocommerce input.button:disabled {
  padding: 12px 30px;
  border-radius: 3px;
  color: #fff;
  background-color: #9c27b0;
  font-family: "Roboto", "Helvetica", "Arial", sans-serif;
  text-transform: uppercase;
}
.woocommerce input.button:disabled[disabled] {
  padding: 12px 30px;
  border-radius: 3px;
  color: #fff;
  background-color: #9c27b0;
  font-family: "Roboto", "Helvetica", "Arial", sans-serif;
  text-transform: uppercase;
}
.woocommerce input.button.alt:hover {
  color: #fff;
  background-color: #9c27b0;
}
.woocommerce input.button:disabled:hover, .woocommerce input.button:disabled[disabled]:hover {
  color: #fff;
  background-color: #9c27b0;
}
.woocommerce .cart-collaterals {
  margin-top: -60px;
  margin-bottom: 46.2px;
}
.woocommerce .cart-collaterals h2 {
  margin: 0 0 4px;
}
.woocommerce .cart-collaterals .cart_totals {
  margin-bottom: 14px;
  width: 44%;
}
.woocommerce .cart-collaterals .cart_totals th, .woocommerce .cart-collaterals .cart_totals td {
  padding: 20px 0;
}
.woocommerce .product .card-product {
  text-align: center;
}
.woocommerce .product .card-product .card-description p {
  margin-bottom: 10px;
  color: #999999;
}
.woocommerce .product .card-product .footer {
  text-align: right;
}
.woocommerce ul.products li.product {
  width: 25%;
  margin: 0;
  background: transparent;
  -webkit-box-shadow: none;
  box-shadow: none;
}
.woocommerce ul.products li.product .price del {
  opacity: 1;
  display: inline;
}
.woocommerce ul.products li.product .price ins {
  text-decoration: none;
}
.woocommerce ul.products li.product .button {
  display: inline-block;
  margin-top: 0;
}
.woocommerce .hestia-features p {
  color: #999999;
}
.woocommerce .related.products {
  margin-top: 100px;
}
.woocommerce .related.products {
  padding-top: 0;
}
.woocommerce .related.products h2 {
  margin: 0 0 50px;
  font-family: "Roboto Slab", "Times New Roman", serif;
  text-align: center;
}
.woocommerce ul.products li.product .price {
  color: #3C4858;
  text-align: right;
}
.woocommerce ul.products li.product .price.price-unit {
  padding: 0 30px 15px;
  margin: -20px 0 10px;
}
.woocommerce nav.woocommerce-pagination ul {
  overflow: visible;
  border: none;
  margin: 20px 0;
}
.woocommerce nav.woocommerce-pagination ul li {
  overflow: visible;
  border: none;
}
.woocommerce nav.woocommerce-pagination ul li span.current {
  min-width: 30px;
  height: 30px;
  margin: 0 3px;
  padding: 0 11px;
  border-color: #9c27b0;
  border-radius: 30px;
  color: #fff;
  background-color: #9c27b0;
  -webkit-box-shadow: 0 4px 5px 0 rgba(156, 39, 176, 0.14), 0 1px 10px 0 rgba(156, 39, 176, 0.12), 0 2px 4px -1px rgba(156, 39, 176, 0.2);
  box-shadow: 0 4px 5px 0 rgba(156, 39, 176, 0.14), 0 1px 10px 0 rgba(156, 39, 176, 0.12), 0 2px 4px -1px rgba(156, 39, 176, 0.2);
}
.woocommerce nav.woocommerce-pagination ul li a {
  min-width: 30px;
  height: 30px;
  margin: 0 3px;
  padding: 0 11px;
  border: 0;
  border-radius: 30px;
  color: #999999;
  background: transparent;
  text-transform: uppercase;
}
.woocommerce nav.woocommerce-pagination ul li a:hover, .woocommerce nav.woocommerce-pagination ul li a:focus {
  background-color: #eee;
}
.woocommerce td.product-name dl.variation dd, .woocommerce td.product-name dl.variation dt {
  margin-bottom: 7px;
  font-size: 14px;
  font-weight: 400;
}
.woocommerce dl.variation dd p {
  margin: 0 0 0 4px;
  padding: 0 0 3.5px;
}
.woocommerce form .form-row .required {
  text-decoration: none;
}
.woocommerce form .form-row .input-checkbox {
  margin: 8px 0 0;
}
.woocommerce .col2-set .woocommerce-account-fields label.checkbox span {
  margin-right: 20px;
}
.woocommerce form.login {
  border: none;
  margin: 0;
  padding: 0;
}
.woocommerce form.login input[type=submit] {
  margin-left: 20px;
}
.woocommerce .before-shop-main {
  margin: 20px 0 25px;
}
.woocommerce .woocommerce-breadcrumb {
  color: #999999;
  margin: 0 0 3px;
}
.woocommerce .woocommerce-breadcrumb a {
  color: #999999;
}
.woocommerce .woocommerce-breadcrumb a:hover {
  color: #3C4858;
}
.woocommerce .woocommerce-result-count {
  color: #3C4858;
}
.woocommerce .woocommerce-ordering,
.woocommerce .woocommerce-result-count {
  margin: 0 !important;
  padding: 0;
}
.woocommerce .woocommerce-ordering {
  margin-top: 10px !important;
}
.woocommerce .woocommerce-ordering:before {
  content: '\f0d7';
  font-family: "Font Awesome 5 Free";
  font-weight: 900;
  position: absolute;
  top: 0;
  left: 0;
  display: inline-block;
  pointer-events: none;
}
.woocommerce .woocommerce-ordering select {
  border: none;
  padding: 0 0 7px 10px;
  text-transform: uppercase;
}
.woocommerce .woocommerce-ordering select:focus {
  background-size: 100% 2px, 100% 1px;
  -webkit-transition-duration: 0.3s;
  transition-duration: 0.3s;
}

.woocommerce.product-card-style-plain .main {
  background-color: #ffffff;
}

.woocommerce-checkout-payment .woocommerce-info {
  color: #3C4858;
  background: #ebe9eb;
  padding: 0 !important;
}
.woocommerce-checkout-payment .woocommerce-info:before {
  display: none;
}

#add_payment_method table.cart td.actions .coupon .input-text,
.woocommerce-cart table.cart td.actions .coupon .input-text,
.woocommerce-checkout table.cart td.actions .coupon .input-text {
  width: auto;
  border: 0;
  margin: 0 0 0 20px;
}

.woocommerce table.shop_table,
.table > thead > tr > th {
  border: none;
}

#add_payment_method table.cart img,
.woocommerce-cart table.cart img,
.woocommerce-checkout table.cart img {
  width: auto;
  -webkit-box-shadow: none;
  box-shadow: none;
}

.woocommerce-cart .woocommerce-cart-form {
  margin-bottom: 15px;
  padding-bottom: 7px;
}
.woocommerce-cart .shop_table .actions .coupon {
  margin-bottom: 15px;
  position: relative;
  padding-bottom: 7px;
}
.woocommerce-cart .shop_table .actions .coupon .input-text {
  height: 36px;
  color: #555;
}
.woocommerce-cart .shop_table .actions .coupon .input-text:focus {
  background-size: 100% 2px, 100% 1px;
  -webkit-transition-duration: 0.3s;
  transition-duration: 0.3s;
}
.woocommerce-cart .shop_table .blockUI.blockOverlay,
.woocommerce-cart .cart-collaterals .blockUI.blockOverlay {
  background-color: white !important;
}

.woocommerce-checkout #customer_details select,
.woocommerce-checkout #order_review select,
.woocommerce-checkout .woocomerce-form select {
  border: none;
}
.woocommerce-checkout #customer_details select:focus,
.woocommerce-checkout #customer_details .input-text:focus,
.woocommerce-checkout #order_review select:focus,
.woocommerce-checkout #order_review .input-text:focus,
.woocommerce-checkout .woocomerce-form select:focus,
.woocommerce-checkout .woocomerce-form .input-text:focus {
  background-size: 100% 2px, 100% 1px;
  -webkit-transition-duration: 0.3s;
  transition-duration: 0.3s;
}

.woocommerce .quantity .qty {
  padding: 4px 0;
}

.card-product > .card-image {
  display: inline-flex;
  box-shadow: 0 5px 15px -8px rgba(0, 0, 0, 0.24), 0 8px 10px -5px rgba(0, 0, 0, 0.2), 0 10px 10px -5px rgba(0, 0, 0, 0.2);
}

.woocommerce div.product div.images img {
  width: auto;
}

.woocommerce ul.products li.product a img {
  display: inline-flex;
}

#add_payment_method .wc-proceed-to-checkout a.checkout-button,
.woocommerce-cart .wc-proceed-to-checkout a.checkout-button,
.woocommerce-checkout .wc-proceed-to-checkout a.checkout-button {
  padding: 12px 30px;
  border-radius: 3px;
  color: #fff;
  background-color: #9c27b0;
  font-family: "Roboto", "Helvetica", "Arial", sans-serif;
  text-transform: uppercase;
}

.added_to_cart.wc-forward {
  border-radius: 3px;
  color: #fff;
  background-color: #9c27b0;
  font-family: "Roboto", "Helvetica", "Arial", sans-serif;
  text-transform: uppercase;
  display: inline-block;
  bottom: -25px;
  width: auto;
  margin: 0 auto;
  padding: 5px 15px;
  text-align: center;
}

.card-product .hestia-view-cart-wrapper {
  bottom: -30px;
  display: block !important;
  overflow: visible;
  position: absolute;
  left: 0;
  right: 0;
  width: 100%;
  text-align: center;
}

.added_to_cart.wc-forward:hover,
.woocommerce-message a.button:hover,
#add_payment_method .wc-proceed-to-checkout a.checkout-button:hover,
.woocommerce-cart .wc-proceed-to-checkout a.checkout-button:hover,
.woocommerce-checkout .wc-proceed-to-checkout a.checkout-button:hover {
  color: #fff;
  background-color: #9c27b0;
}

.woocommerce-page ul.products li.product {
  width: 25%;
  margin: 0;
  padding: 0 15px;
  background: transparent;
  -webkit-box-shadow: none;
  box-shadow: none;
}
.woocommerce-page.woocommerce-cart .woocommerce ul.products li.first {
  clear: both;
}

.woocommerce-cart table.shop_table th {
  padding: 20px;
  text-transform: uppercase;
}
.woocommerce-cart table.shop_table .product-name a {
  color: #3C4858;
}
.woocommerce-cart table.shop_table td {
  padding: 20px;
}
.woocommerce-cart table.shop_table td.product-remove {
  width: 21px;
}
.woocommerce-cart table.shop_table td.product-thumbnail {
  width: 100px;
}
.woocommerce-cart table.shop_table td.actions {
  padding: 20px 0;
}

.woocommerce-page .title-row {
  margin-top: 20px;
}

.single-product.woocommerce .thumbnails #slider-prev, .single-product.woocommerce .thumbnails #slider-next {
  top: 45% !important;
}

.variations tr {
  border: none;
}
.variations tr .label {
  color: #aaa;
}

.woocommerce-account form.login {
  border: 1px solid #d3ced2;
  padding: 20px;
  margin: 2em 0;
}

.woocommerce ul.products[class*="columns-"] li.product-category.product {
  margin-top: 30px;
  padding: 0 15px;
}
.woocommerce ul.products[class*="columns-"] li.product-category.product a {
  background: #fff;
  border-radius: 6px;
  display: inline-block;
  padding: 0 15px 15px;
  margin: 0 0 30px;
  -webkit-box-shadow: 0 2px 2px 0 rgba(0, 0, 0, 0.14), 0 3px 1px -2px rgba(0, 0, 0, 0.2), 0 1px 5px 0 rgba(0, 0, 0, 0.12);
  -moz-box-shadow: 0 2px 2px 0 rgba(0, 0, 0, 0.14), 0 3px 1px -2px rgba(0, 0, 0, 0.2), 0 1px 5px 0 rgba(0, 0, 0, 0.12);
  box-shadow: 0 2px 2px 0 rgba(0, 0, 0, 0.14), 0 3px 1px -2px rgba(0, 0, 0, 0.2), 0 1px 5px 0 rgba(0, 0, 0, 0.12);
}
.woocommerce ul.products[class*="columns-"] li.product-category.product a h2 {
  padding-top: 15px;
  text-align: center;
}
.woocommerce ul.products[class*="columns-"] li.product-category.product a h2 .count {
  font-weight: 500;
  background: none;
  color: #999;
  display: block;
  padding: 0;
}
.woocommerce ul.products[class*="columns-"] li.product-category.product a img {
  border-radius: 6px;
  display: inline-block;
  margin: -30px 0 0;
  -webkit-transform: translate(0, 0);
  -moz-transform: translate(0, 0);
  -ms-transform: translate(0, 0);
  -o-transform: translate(0, 0);
  transform: translate(0, 0);
  -webkit-box-shadow: 0 5px 15px -8px rgba(0, 0, 0, 0.24), 0 8px 10px -5px rgba(0, 0, 0, 0.2), 0 10px 10px -5px rgba(0, 0, 0, 0.2);
  -moz-box-shadow: 0 5px 15px -8px rgba(0, 0, 0, 0.24), 0 8px 10px -5px rgba(0, 0, 0, 0.2), 0 10px 10px -5px rgba(0, 0, 0, 0.2);
  box-shadow: 0 5px 15px -8px rgba(0, 0, 0, 0.24), 0 8px 10px -5px rgba(0, 0, 0, 0.2), 0 10px 10px -5px rgba(0, 0, 0, 0.2);
}
.woocommerce ul.products[class*="columns-"] li.product-category.product:hover a img {
  -webkit-transform: translate(0, -10px);
  -moz-transform: translate(0, -10px);
  -ms-transform: translate(0, -10px);
  -o-transform: translate(0, -10px);
  transform: translate(0, -10px);
  -webkit-box-shadow: 0 15px 35px -15px rgba(0, 0, 0, 0.5), 0 5px 25px 0 rgba(0, 0, 0, 0.12), 0 10px 10px -5px rgba(0, 0, 0, 0.2);
  -moz-box-shadow: 0 15px 35px -15px rgba(0, 0, 0, 0.5), 0 5px 25px 0 rgba(0, 0, 0, 0.12), 0 10px 10px -5px rgba(0, 0, 0, 0.2);
  box-shadow: 0 15px 35px -15px rgba(0, 0, 0, 0.5), 0 5px 25px 0 rgba(0, 0, 0, 0.12), 0 10px 10px -5px rgba(0, 0, 0, 0.2);
}
.woocommerce ul.products[class*="columns-"] li.product-category.product.card-plain a {
  box-shadow: none;
}
.woocommerce ul.products[class*="columns-"] li.product-category.product.card-plain a img {
  box-shadow: none;
  border-radius: 3px;
}
.woocommerce ul.products[class*="columns-"] li.product-category.product.swap-images:hover a:hover {
  opacity: inherit;
}
.woocommerce ul.products[class*="columns-"] li.product-category.product.swap-images:hover a img {
  transform: none;
}

#products .hestia-shop-content .products li {
  margin-top: 30px;
}

@media (max-width: 768px) {
  .woocommerce-cart .wrapper.no-content .main, .woocommerce-cart .wrapper.classic-blog .main,
  .woocommerce-checkout .wrapper.no-content .main,
  .woocommerce-checkout .wrapper.classic-blog .main {
    margin-top: 70px;
  }
}
@media (max-width: 600px) {
  .woocommerce-cart .wrapper.no-content .main, .woocommerce-cart .wrapper.classic-blog .main,
  .woocommerce-checkout .wrapper.no-content .main,
  .woocommerce-checkout .wrapper.classic-blog .main {
    margin-top: 30px;
  }
}
.woocommerce-cart .no-content article.section,
.woocommerce-checkout .no-content article.section {
  padding-top: 0;
  padding-bottom: 70px;
}
.woocommerce-cart .wrapper.no-content article .hestia-title,
.woocommerce-checkout .wrapper.no-content article .hestia-title {
  margin-top: 60px;
  margin-bottom: 30px;
}
@media (max-width: 768px) {
  .woocommerce-cart .wrapper.no-content article .hestia-title,
  .woocommerce-checkout .wrapper.no-content article .hestia-title {
    margin-top: 30px;
  }
}
.woocommerce-cart .wrapper.classic-blog article,
.woocommerce-checkout .wrapper.classic-blog article {
  margin: 0 0 70px;
}
.woocommerce-cart .wrapper.default article,
.woocommerce-checkout .wrapper.default article {
  padding: 60px 0 70px;
}
@media (max-width: 768px) {
  .woocommerce-cart .wrapper.default article,
  .woocommerce-checkout .wrapper.default article {
    padding: 36px 0 70px;
  }
}

.woocommerce-cart .blog-post .woocommerce .woocommerce-cart-form {
  float: right;
  width: 65%;
}
.woocommerce-cart .blog-post .woocommerce .cart-collaterals {
  float: left;
  margin-top: 0;
  width: 30%;
}
.woocommerce-cart .blog-post .woocommerce .cart-collaterals .cart_totals {
  width: 100%;
}
.woocommerce-cart .blog-post .woocommerce .cart-collaterals .cart_totals .checkout-button {
  margin-bottom: 0;
}
.woocommerce-cart .blog-post .woocommerce .cart-collaterals .cart_totals .woocommerce-shipping-calculator {
  padding-bottom: 0;
  margin-bottom: 0;
}
.woocommerce-cart .blog-post .woocommerce .cart-collaterals .cart_totals .woocommerce-shipping-calculator > p {
  margin-bottom: 0;
}
.woocommerce-cart table.shop_table td.actions input[type=submit],
.woocommerce-cart table.shop_table td.actions button[type=submit] {
  background: transparent;
  border: 1px solid #999999;
  box-shadow: none;
  color: #999999;
  padding: 12px 30px;
}
.woocommerce-cart table.shop_table td.actions input[type=submit]:hover,
.woocommerce-cart table.shop_table td.actions button[type=submit]:hover {
  background: #999999;
  box-shadow: none;
  color: #fff;
}
.woocommerce-cart table.shop_table td.actions input[type=submit]:disabled:hover,
.woocommerce-cart table.shop_table td.actions button[type=submit]:disabled:hover {
  background: transparent;
  color: #999999;
}

.woocommerce-checkout .blog-post .section form.woocommerce-checkout h3 {
  margin-top: 0;
}

.woocommerce #reviews #comments ol.commentlist li .comment-text p.meta .woocommerce-review__author {
  font-family: "Roboto Slab", "Times New Roman", serif;
}

.woocommerce .single-product div.product form.cart .button, .woocommerce #respond input#submit, .woocommerce a.button, .woocommerce button.button, .woocommerce input.button, .woocommerce #respond input#submit.alt, .woocommerce a.button.alt, .woocommerce button.button.alt, .woocommerce input.button.alt, .woocommerce input.button:disabled, .woocommerce input.button[disabled]:disabled, #add_payment_method .wc-proceed-to-checkout a.checkout-button,
.woocommerce-cart .wc-proceed-to-checkout a.checkout-button,
.woocommerce-checkout .wc-proceed-to-checkout a.checkout-button, .added_to_cart.wc-forward {
  -webkit-box-shadow: 0 2px 2px 0 rgba(156, 39, 176, 0.14), 0 3px 1px -2px rgba(156, 39, 176, 0.2), 0 1px 5px 0 rgba(156, 39, 176, 0.12);
  -moz-box-shadow: 0 2px 2px 0 rgba(156, 39, 176, 0.14), 0 3px 1px -2px rgba(156, 39, 176, 0.2), 0 1px 5px 0 rgba(156, 39, 176, 0.12);
  box-shadow: 0 2px 2px 0 rgba(156, 39, 176, 0.14), 0 3px 1px -2px rgba(156, 39, 176, 0.2), 0 1px 5px 0 rgba(156, 39, 176, 0.12);
}

.woocommerce input.button.alt:hover, .woocommerce input.button:disabled:hover, .woocommerce input.button[disabled]:disabled:hover, .added_to_cart.wc-forward:hover,
.woocommerce-message a.button:hover,
#add_payment_method .wc-proceed-to-checkout a.checkout-button:hover,
.woocommerce-cart .wc-proceed-to-checkout a.checkout-button:hover,
.woocommerce-checkout .wc-proceed-to-checkout a.checkout-button:hover, .widget_shopping_cart.widget .remove:hover {
  -webkit-box-shadow: 0 14px 26px -12px rgba(156, 39, 176, 0.42), 0 4px 23px 0 rgba(0, 0, 0, 0.12), 0 8px 10px -5px rgba(156, 39, 176, 0.2);
  -moz-box-shadow: 0 14px 26px -12px rgba(156, 39, 176, 0.42), 0 4px 23px 0 rgba(0, 0, 0, 0.12), 0 8px 10px -5px rgba(156, 39, 176, 0.2);
  box-shadow: 0 14px 26px -12px rgba(156, 39, 176, 0.42), 0 4px 23px 0 rgba(0, 0, 0, 0.12), 0 8px 10px -5px rgba(156, 39, 176, 0.2);
}

.woocommerce div.product .woocommerce-product-gallery--columns-4 .flex-control-thumbs li:nth-child(4n+1) {
  clear: none;
}

.woocommerce ul.products li.product .card-description h1,
.card-product .card-description h1 {
  font-size: 21px;
  margin: 0 0 8px;
  line-height: normal;
}
.woocommerce ul.products li.product .card-description h2,
.card-product .card-description h2 {
  font-size: 18px;
  margin: 0 0 6px;
  line-height: normal;
}
.woocommerce ul.products li.product .card-description h3,
.card-product .card-description h3 {
  font-size: 16px;
  margin: 0 0 3px;
  line-height: normal;
  padding: 0;
}
.woocommerce ul.products li.product .card-description h4, .woocommerce ul.products li.product .card-description h5, .woocommerce ul.products li.product .card-description h6,
.card-product .card-description h4,
.card-product .card-description h5,
.card-product .card-description h6 {
  font-size: 14px;
  margin: 0 0 3px;
  line-height: normal;
}

.woocommerce-cart .woocommerce-cart-form {
  margin-bottom: 0;
  padding-bottom: 0;
}
@media (max-width: 991px) {
  .woocommerce-cart .woocommerce-cart-form {
    margin-bottom: 15px;
    padding-bottom: 7px;
  }
}
.woocommerce-cart .cross-sells {
  width: 65%;
  float: right;
}
.woocommerce-cart .cross-sells h2 {
  margin-top: 20px;
  margin-bottom: 10px;
}
@media (max-width: 991px) {
  .woocommerce-cart .cross-sells {
    width: 100%;
  }
}

.products .shop-item {
  margin-top: 30px;
}

.single-product .hestia-features,
.single-product .features {
  padding: 50px 0 0;
}
.single-product .hestia-features .hestia-info > p, .single-product .hestia-features .info > p,
.single-product .features .hestia-info > p,
.single-product .features .info > p {
  margin-bottom: 10px;
}

.wrapper.classic-blog .before-shop-main, .wrapper.no-content .before-shop-main {
  margin-top: 0;
  padding-top: 40px;
}
@media (max-width: 768px) {
  .wrapper.classic-blog .before-shop-main, .wrapper.no-content .before-shop-main {
    padding-top: 30px;
  }
}

/* Shop section on any page, even when using a shortcode to display the section */
/* Style card-product to be same as WooCommerce archive when less than 3 products per row */
.hestia-shop-content .shop-item.col-ms-6.col-sm-6 {
  text-align: center;
}
.hestia-shop-content .shop-item.col-ms-6.col-sm-6 .card-product {
  width: auto;
}
.hestia-shop-content .shop-item.col-ms-6.col-sm-6 .card-product .card-image > a > img {
  max-width: 230px;
}
.hestia-shop-content .shop-item.col-ms-6.col-sm-6 .card-product .content {
  max-width: 230px;
  margin-right: auto;
  margin-left: auto;
}

/* White background on shop section when the second layout for card-product is enabled */
body.product-card-style-plain .hestia-shop {
  background-color: #ffffff;
}

@media (min-width: 768px) {
  .home section.products .col-md-3.shop-item {
    display: inline-block;
    float: none !important;
    margin-left: -3px;
    margin-right: -2px;
  }
  .home section.products .row {
    text-align: center;
  }
}
@media (min-width: 481px) and (max-width: 991px) {
  .hestia-shop-content .shop-item.col-sm-6.col-ms-6 {
    text-align: left;
  }

  .hestia-shop-content .shop-item.col-sm-6.col-ms-6:nth-of-type(2n) {
    text-align: right;
  }
}
.woocommerce.single-product .header-filter {
  background-position: top center;
}

/*--------------------------------------------------------------
## Typography
--------------------------------------------------------------*/
.hestia-top-bar .widget.widget_shopping_cart:before,
.header-widgets-wrapper .widget.widget_shopping_cart:before {
  font-size: 18px;
}
.hestia-top-bar .widget.widget_shopping_cart .cart_list li.empty,
.header-widgets-wrapper .widget.widget_shopping_cart .cart_list li.empty {
  font-size: inherit;
  line-height: 1.2;
}

.woocommerce ul.product_list_widget li,
.footer ul.product_list_widget li,
ul.product_list_widget li {
  font-size: 14px;
}
.woocommerce ul.product_list_widget li a,
.footer ul.product_list_widget li a,
ul.product_list_widget li a {
  line-height: normal;
  font-weight: 400;
}

#secondary div[id^=woocommerce_rating_filter] li a,
.footer div[id^=woocommerce_rating_filter] li a {
  font-weight: 300;
}
#secondary div[id^=woocommerce_layered_nav] ul li a,
#secondary div[id^=woocommerce_product_categories] ul li a,
.footer div[id^=woocommerce_layered_nav] ul li a,
.footer div[id^=woocommerce_product_categories] ul li a {
  font-weight: 400;
  font-size: 14px;
}
#secondary div[id^=woocommerce_layered_nav] ul .count,
#secondary div[id^=woocommerce_product_categories] ul .count,
.footer div[id^=woocommerce_layered_nav] ul .count,
.footer div[id^=woocommerce_product_categories] ul .count {
  font-size: 14px;
}
#secondary div[id^=woocommerce_recent_reviews] .reviewer,
.footer div[id^=woocommerce_recent_reviews] .reviewer {
  font-size: 15px;
}
#secondary div[id^=woocommerce_price_filter] .button,
.footer div[id^=woocommerce_price_filter] .button {
  font-size: 12px;
}
#secondary div[id^=woocommerce_price_filter] .price_slider,
.footer div[id^=woocommerce_price_filter] .price_slider {
  font-size: inherit;
  line-height: inherit;
}
#secondary div[id^=woocommerce_price_filter] .price_label,
.footer div[id^=woocommerce_price_filter] .price_label {
  font-size: 14px;
}

div[id^=woocommerce_product_tag_cloud].widget a {
  font-weight: 600;
  line-height: 27px;
  font-size: 10px !important;
}

div[id^=woocommerce_layered_nav_filters].widget li a {
  font-weight: 100;
}

.widget_shopping_cart.widget .remove {
  font-size: 18px;
  line-height: 18px;
  font-weight: 600;
}
.widget_shopping_cart.widget .variation dt,
.widget_shopping_cart.widget .variation dd {
  font-size: 12px;
  line-height: 14px;
}
.widget_shopping_cart.widget .variation dd p {
  font-size: 12px;
  line-height: 14px;
}

.woocommerce.single-product .product_title {
  font-weight: 700;
}
.woocommerce.single-product .summary .price,
.woocommerce.single-product .woocommerce-variation-price .price {
  font-weight: 300;
}
.woocommerce.single-product .summary .price del,
.woocommerce.single-product .summary .price ins,
.woocommerce.single-product .summary .price span,
.woocommerce.single-product .woocommerce-variation-price .price del,
.woocommerce.single-product .woocommerce-variation-price .price ins,
.woocommerce.single-product .woocommerce-variation-price .price span {
  font-weight: 300;
}
.woocommerce.single-product .summary .price ins {
  font-weight: 400;
}
.woocommerce.single-product .summary .price.price-unit {
  font-size: 16px;
}
.woocommerce.single-product div.product form.cart table.variations td.value:before {
  font-size: 12px;
}
.woocommerce.single-product div.product form.cart table.variations td label {
  font-weight: 400;
}
.woocommerce.single-product div.product form.cart .reset_variations {
  font-size: 14px;
}
.woocommerce.single-product div.product .woocommerce-tabs ul.tabs.wc-tabs li a {
  font-size: 14px;
  font-weight: 400;
  line-height: 24px;
}
.woocommerce.single-product .product .woocommerce-product-rating .star-rating {
  font-size: 12px;
}
.woocommerce.single-product .product .woocommerce-review-link {
  font-size: 14px;
}
.woocommerce.single-product .section-text {
  font-size: 14px;
}
.woocommerce .shop-item p {
  font-size: 14px;
}
.woocommerce ul.products li.product .onsale,
.woocommerce span.onsale {
  font-size: 12px;
  font-weight: 300;
  line-height: 50px;
}
.woocommerce .single-product div.product form.cart .button,
.woocommerce #respond input#submit,
.woocommerce a.button,
.woocommerce button.button,
.woocommerce input.button,
.woocommerce #respond input#submit.alt,
.woocommerce a.button.alt,
.woocommerce button.button.alt {
  font-size: 12px;
  font-weight: 400;
}
.woocommerce input.button.alt {
  font-size: 12px;
  font-weight: 400;
}
.woocommerce input.button:disabled {
  font-size: 12px;
  font-weight: 400;
}
.woocommerce input.button[disabled] {
  font-size: 12px;
  font-weight: 400;
}
.woocommerce .cart-collaterals .cart_totals th {
  font-weight: 300;
}
.woocommerce .cart-collaterals .cart_totals td {
  font-weight: 700;
}
.woocommerce .cart-collaterals .cart_totals .checkout-button {
  font-size: 14px;
}
.woocommerce .product .card-product .card-description p {
  font-weight: 300;
}
.woocommerce ul.products li.product .price ins {
  font-weight: 300;
}
.woocommerce .hestia-features p {
  font-weight: 300;
}
.woocommerce .related.products h2 {
  font-weight: 700;
}
.woocommerce ul.products li.product .price {
  font-weight: 300;
}
.woocommerce ul.products li.product .price.price-unit {
  font-size: 12px;
}
.woocommerce nav.woocommerce-pagination ul li a {
  font-size: 14px;
  font-weight: 400;
  line-height: 30px;
}
.woocommerce nav.woocommerce-pagination ul li span {
  line-height: 30px;
}
.woocommerce dl.variation dd p {
  font-size: 14px;
}
.woocommerce .col2-set .woocommerce-account-fields label.checkbox span {
  font-weight: 300;
}
.woocommerce .woocommerce-breadcrumb {
  font-size: 12px;
}
.woocommerce .section-text {
  font-size: 14px;
}
.woocommerce .woocommerce-result-count {
  font-size: 14px;
}
.woocommerce ul.products li.product .onsale,
.woocommerce span.onsale {
  font-size: 12px;
  font-weight: 300;
  line-height: 35px;
  border-radius: 3px;
  width: auto;
  height: auto;
}
.woocommerce .woocommerce-ordering:before {
  font-size: 12px;
}
.woocommerce .product .wc-gzd-additional-info {
  font-size: 12px;
  line-height: 1.5;
}
.woocommerce .comment-reply-title {
  font-weight: 700;
}
.woocommerce #reviews #comments ol.commentlist li .comment-text p.meta .woocommerce-review__dash,
.woocommerce #reviews #comments ol.commentlist li .comment-text p.meta .woocommerce-review__published-date {
  font-size: 75%;
}
.woocommerce.archive .blog-post .products li.product-category a h2 {
  line-height: 1.5;
}
.woocommerce.archive .blog-post .products li.product-category a h2 .count {
  font-weight: 300;
}

.products .shop-item .added_to_cart {
  font-size: 10px;
}

/*--------------------------------------------------------------
## Widgets
--------------------------------------------------------------*/
.shop-sidebar.card {
  padding-top: 29px;
  padding-right: 15px;
  padding-left: 15px;
}

.woocommerce ul.cart_list li dl::after, .woocommerce ul.product_list_widget li dl::after {
  clear: right;
}

.woocommerce ul.product_list_widget, .footer ul.product_list_widget, ul.product_list_widget {
  padding: 0;
}
.woocommerce ul.product_list_widget li, .footer ul.product_list_widget li, ul.product_list_widget li {
  padding: 10px 0;
}
.woocommerce ul.product_list_widget li:after, .footer ul.product_list_widget li:after, ul.product_list_widget li:after {
  content: " ";
  display: block;
  height: 0;
  clear: both;
}
.woocommerce ul.product_list_widget li a, .footer ul.product_list_widget li a, ul.product_list_widget li a {
  padding: 0;
  display: block;
  margin-bottom: 8px;
}
.woocommerce ul.product_list_widget li img, .footer ul.product_list_widget li img, ul.product_list_widget li img {
  float: left;
  -webkit-transition: all 300ms cubic-bezier(0.34, 1.61, 0.7, 1);
  -moz-transition: all 300ms cubic-bezier(0.34, 1.61, 0.7, 1);
  -o-transition: all 300ms cubic-bezier(0.34, 1.61, 0.7, 1);
  -ms-transition: all 300ms cubic-bezier(0.34, 1.61, 0.7, 1);
  transition: all 300ms cubic-bezier(0.34, 1.61, 0.7, 1);
  border-radius: 6px;
  margin-right: 20px;
  width: 70px;
  -webkit-box-shadow: 0 2px 2px 0 rgba(0, 0, 0, 0.14), 0 3px 1px -2px rgba(0, 0, 0, 0.2), 0 1px 5px 0 rgba(0, 0, 0, 0.12);
  -moz-box-shadow: 0 2px 2px 0 rgba(0, 0, 0, 0.14), 0 3px 1px -2px rgba(0, 0, 0, 0.2), 0 1px 5px 0 rgba(0, 0, 0, 0.12);
  box-shadow: 0 2px 2px 0 rgba(0, 0, 0, 0.14), 0 3px 1px -2px rgba(0, 0, 0, 0.2), 0 1px 5px 0 rgba(0, 0, 0, 0.12);
}
.woocommerce ul.product_list_widget li:hover img, .footer ul.product_list_widget li:hover img, ul.product_list_widget li:hover img {
  transform: translateY(-3px);
  -webkit-box-shadow: 0 2px 2px 0 rgba(0, 0, 0, 0.14), 0 3px 6px -2px rgba(0, 0, 0, 0.2), 0 4px 5px 0 rgba(0, 0, 0, 0.12);
  -moz-box-shadow: 0 2px 2px 0 rgba(0, 0, 0, 0.14), 0 3px 6px -2px rgba(0, 0, 0, 0.2), 0 4px 5px 0 rgba(0, 0, 0, 0.12);
  box-shadow: 0 2px 2px 0 rgba(0, 0, 0, 0.14), 0 3px 6px -2px rgba(0, 0, 0, 0.2), 0 4px 5px 0 rgba(0, 0, 0, 0.12);
}
.woocommerce ul.product_list_widget li .quantity, .footer ul.product_list_widget li .quantity, ul.product_list_widget li .quantity {
  display: block;
}
.woocommerce ul.product_list_widget li:first-child, .footer ul.product_list_widget li:first-child, ul.product_list_widget li:first-child {
  padding-top: 0;
}

.star-rating {
  color: #ff9800;
  overflow: hidden;
  position: relative;
  height: 12px;
  width: 64.8px;
  font-family: star;
}
.star-rating:before {
  content: '\73\73\73\73\73';
  color: #d3ced2;
  float: right;
  top: 0;
  right: 0;
  position: absolute;
}
.star-rating span {
  position: absolute;
  padding-top: 18px;
}
.star-rating span:before {
  content: '\53\53\53\53\53';
  top: 0;
  position: absolute;
  right: 0;
}

#secondary div[id^=woocommerce_rating_filter] li,
.footer div[id^=woocommerce_rating_filter] li {
  text-align: left;
}
#secondary div[id^=woocommerce_rating_filter] li .star-rating,
.footer div[id^=woocommerce_rating_filter] li .star-rating {
  float: right;
  margin-top: 8px;
}

.footer div[id^=woocommerce_rating_filter] li > a {
  display: block;
}

#secondary div[id^=woocommerce_layered_nav] ul,
#secondary div[id^=woocommerce_product_categories] ul,
.footer div[id^=woocommerce_layered_nav] ul,
.footer div[id^=woocommerce_product_categories] ul {
  padding: 0;
}
#secondary div[id^=woocommerce_layered_nav] ul.children,
#secondary div[id^=woocommerce_product_categories] ul.children,
.footer div[id^=woocommerce_layered_nav] ul.children,
.footer div[id^=woocommerce_product_categories] ul.children {
  padding-right: 15px;
}
#secondary div[id^=woocommerce_layered_nav] ul .count,
#secondary div[id^=woocommerce_product_categories] ul .count,
.footer div[id^=woocommerce_layered_nav] ul .count,
.footer div[id^=woocommerce_product_categories] ul .count {
  float: left;
}

#secondary div[id^=woocommerce_products] a .product-title,
#secondary div[id^=woocommerce_top_rated_products] a .product-title,
#secondary div[id^=woocommerce_recently_viewed_products] a .product-title,
.footer div[id^=woocommerce_products] a .product-title,
.footer div[id^=woocommerce_top_rated_products] a .product-title,
.footer div[id^=woocommerce_recently_viewed_products] a .product-title {
  margin-top: 20px;
}
#secondary div[id^=woocommerce_products] .amount:first-of-type,
#secondary div[id^=woocommerce_products] ins,
#secondary div[id^=woocommerce_top_rated_products] .amount:first-of-type,
#secondary div[id^=woocommerce_top_rated_products] ins,
#secondary div[id^=woocommerce_recently_viewed_products] .amount:first-of-type,
#secondary div[id^=woocommerce_recently_viewed_products] ins,
.footer div[id^=woocommerce_products] .amount:first-of-type,
.footer div[id^=woocommerce_products] ins,
.footer div[id^=woocommerce_top_rated_products] .amount:first-of-type,
.footer div[id^=woocommerce_top_rated_products] ins,
.footer div[id^=woocommerce_recently_viewed_products] .amount:first-of-type,
.footer div[id^=woocommerce_recently_viewed_products] ins {
  text-decoration: none;
}
#secondary div[id^=woocommerce_products] ins .amount,
#secondary div[id^=woocommerce_top_rated_products] ins .amount,
#secondary div[id^=woocommerce_recently_viewed_products] ins .amount,
.footer div[id^=woocommerce_products] ins .amount,
.footer div[id^=woocommerce_top_rated_products] ins .amount,
.footer div[id^=woocommerce_recently_viewed_products] ins .amount {
  margin-right: 10px !important;
}

#secondary div[id^=woocommerce_recent_reviews] ul.product_list_widget li > a > img,
.footer div[id^=woocommerce_recent_reviews] ul.product_list_widget li > a > img {
  width: 70px;
}

#secondary div[id^=woocommerce_price_filter],
.footer div[id^=woocommerce_price_filter] {
  padding-left: 14px;
}
#secondary div[id^=woocommerce_price_filter] .price_slider,
.footer div[id^=woocommerce_price_filter] .price_slider {
  background-color: #c8c8c8;
  height: 2px;
  margin: 15px 0 30px;
  border-radius: 5px;
}
#secondary div[id^=woocommerce_price_filter] .price_slider .ui-slider-range,
.footer div[id^=woocommerce_price_filter] .price_slider .ui-slider-range {
  background-color: #9c27b0;
  height: 2px;
  display: block;
  position: absolute;
}
#secondary div[id^=woocommerce_price_filter] .price_slider .ui-slider-handle,
.footer div[id^=woocommerce_price_filter] .price_slider .ui-slider-handle {
  margin-top: -6px;
  margin-right: 0;
  background: #fff;
  border: 1px solid #9c27b0;
  border-radius: 50%;
  height: 14px;
  width: 14px;
  position: absolute;
  top: 0;
  -webkit-box-shadow: 0 2px 2px 0 rgba(0, 0, 0, 0.14), 0 3px 1px -2px rgba(0, 0, 0, 0.2), 0 1px 5px 0 rgba(0, 0, 0, 0.12);
  -moz-box-shadow: 0 2px 2px 0 rgba(0, 0, 0, 0.14), 0 3px 1px -2px rgba(0, 0, 0, 0.2), 0 1px 5px 0 rgba(0, 0, 0, 0.12);
  box-shadow: 0 2px 2px 0 rgba(0, 0, 0, 0.14), 0 3px 1px -2px rgba(0, 0, 0, 0.2), 0 1px 5px 0 rgba(0, 0, 0, 0.12);
  transition: transform .3s ease;
  cursor: pointer;
}
#secondary div[id^=woocommerce_price_filter] .price_slider .ui-slider-handle:focus,
.footer div[id^=woocommerce_price_filter] .price_slider .ui-slider-handle:focus {
  outline: none;
}
#secondary div[id^=woocommerce_price_filter] .price_slider .ui-slider-handle.ui-state-active, #secondary div[id^=woocommerce_price_filter] .price_slider .ui-slider-handle:hover,
.footer div[id^=woocommerce_price_filter] .price_slider .ui-slider-handle.ui-state-active,
.footer div[id^=woocommerce_price_filter] .price_slider .ui-slider-handle:hover {
  transform: scale3d(1.5, 1.5, 1);
}
#secondary div[id^=woocommerce_price_filter] .button,
.footer div[id^=woocommerce_price_filter] .button {
  margin-left: -14px;
  float: left !important;
}
#secondary div[id^=woocommerce_price_filter] .price_slider,
.footer div[id^=woocommerce_price_filter] .price_slider {
  text-align: right;
}
#secondary div[id^=woocommerce_price_filter] .price_label,
.footer div[id^=woocommerce_price_filter] .price_label {
  max-width: 50%;
  padding-top: 0;
  text-align: right;
}

div[id^=woocommerce_product_tag_cloud].widget a {
  padding: 5px 12px;
  border-radius: 12px;
  text-transform: uppercase;
  background: #9c27b0;
  color: #fff;
  margin-bottom: 5px;
  white-space: nowrap;
}

.widget_shopping_cart.widget img {
  width: 70px;
  float: left;
  margin-right: 20px;
  margin-left: 0;
}
.widget_shopping_cart.widget .remove,
.widget_shopping_cart.widget .total .amount,
.widget_shopping_cart.widget .buttons .button:last-child {
  float: left;
}
.widget_shopping_cart.widget .remove {
  color: #f44336;
  border-radius: 50%;
  height: 18px;
  width: 18px;
  text-align: center;
  top: -2px;
  z-index: 1;
}
.widget_shopping_cart.widget .remove:hover {
  color: #fff;
  background: #f44336;
}
.widget_shopping_cart.widget .buttons .button {
  color: #fff;
  display: inline-block;
}
.widget_shopping_cart.widget .buttons:after {
  content: " ";
  display: block;
  height: 0;
  clear: both;
}
.widget_shopping_cart.widget .variation {
  border-right: 0;
  padding-right: 0;
}
.widget_shopping_cart.widget .variation dt,
.widget_shopping_cart.widget .variation dd {
  padding: 0;
  margin: 0 0 0 4px;
}

.woocommerce-product-search {
  width: 100%;
}
.woocommerce-product-search input.search-field {
  display: table-cell;
  vertical-align: top;
  float: right;
  width: 70%;
}

div[id^=woocommerce_product_search].widget,
div[id^=search].widget {
  margin-bottom: 0;
}
div[id^=woocommerce_product_search].widget .search-form,
div[id^=woocommerce_product_search].widget .woocommerce-product-search,
div[id^=search].widget .search-form,
div[id^=search].widget .woocommerce-product-search {
  margin-bottom: 0;
  padding-bottom: 0;
}

div[id^=woocommerce_layered_nav_filters].widget li {
  width: 100%;
  display: inline;
}
div[id^=woocommerce_layered_nav_filters].widget li a:before {
  color: red;
}

.header-widgets-wrapper .widget.widget_shopping_cart {
  margin-top: 7px;
  cursor: pointer;
  position: relative;
}
.header-widgets-wrapper .widget.widget_shopping_cart .button.checkout {
  display: none;
}
.header-widgets-wrapper .widget.widget_shopping_cart .wc-forward:not(.checkout) {
  opacity: 0;
  position: absolute;
  top: -5px;
  right: -4px;
  padding: 0;
}
.header-widgets-wrapper .widget.widget_shopping_cart:before {
  color: #333;
  content: "\f07a";
  font-family: "Font Awesome 5 Free";
  font-weight: 900;
  margin-left: 5px;
}
.header-widgets-wrapper .widget.widget_shopping_cart:hover .cart_list {
  opacity: 1;
  display: block;
  visibility: visible;
  margin-top: 10px;
}
.header-widgets-wrapper .widget.widget_shopping_cart h5 {
  display: none;
}
.header-widgets-wrapper .widget.widget_shopping_cart .widget_shopping_cart_content {
  display: inline-block;
}
.header-widgets-wrapper .widget.widget_shopping_cart .cart_list {
  margin-top: 0;
  display: block;
  visibility: hidden;
  transition: all .3s ease;
  opacity: 0;
  padding: 0 15px 15px;
  position: absolute;
  left: 0;
  top: 15px;
  z-index: 10;
  border: 0;
  -webkit-box-shadow: 0 2px 5px 0 rgba(0, 0, 0, 0.26);
  box-shadow: 0 2px 5px 0 rgba(0, 0, 0, 0.26);
  border-radius: 3px !important;
  background: #fff;
}
.header-widgets-wrapper .widget.widget_shopping_cart .cart_list li {
  color: #333;
  display: block;
  margin-top: 15px;
  padding-bottom: 0;
  white-space: nowrap;
}
.header-widgets-wrapper .widget.widget_shopping_cart .cart_list li a:not(.remove) {
  color: #333;
  margin: 0;
  padding-left: 65px;
  text-align: right;
}
.header-widgets-wrapper .widget.widget_shopping_cart .cart_list li img {
  float: right;
  width: 50px;
  margin-right: 0;
  margin-left: 15px;
}
.header-widgets-wrapper .widget.widget_shopping_cart .cart_list li .quantity {
  float: right;
}
.header-widgets-wrapper .widget.widget_shopping_cart .cart_list li .variation {
  display: none;
}
.header-widgets-wrapper .widget.widget_shopping_cart .cart_list li.empty {
  padding: 0;
}
.header-widgets-wrapper .widget.widget_shopping_cart .total {
  border: none;
  margin: 0;
  padding: 0;
}
.header-widgets-wrapper .widget.widget_shopping_cart .total strong {
  display: none;
}
.header-widgets-wrapper .widget.widget_shopping_cart .total .amount {
  float: none;
}

.navbar-transparent .widget.widget_shopping_cart:before {
  color: #fff;
}

.woocommerce-product-search {
  width: 100%;
}
.woocommerce-product-search input[type=submit], .woocommerce-product-search button {
  float: left;
}
.woocommerce-product-search input[type=search] {
  display: table-cell;
  vertical-align: top;
  float: right;
  width: 70%;
}

.hestia-top-bar .widget.widget_shopping_cart {
  cursor: pointer;
  padding-right: 25px;
  position: relative;
  vertical-align: top;
}
.hestia-top-bar .widget.widget_shopping_cart:before {
  color: #fff;
  content: "\f07a";
  font-family: "Font Awesome 5 Free";
  font-weight: 900;
  position: absolute;
  right: 0;
  top: 0;
  z-index: 50;
}
.hestia-top-bar .widget.widget_shopping_cart:hover .cart_list {
  display: inline-block;
  opacity: 1;
  visibility: visible;
  margin-top: 0;
}
.hestia-top-bar .widget.widget_shopping_cart .button.checkout {
  display: none;
}
.hestia-top-bar .widget.widget_shopping_cart .wc-forward:not(.checkout) {
  opacity: 0;
  position: absolute;
  top: -5px;
  right: -4px;
}
.hestia-top-bar .widget.widget_shopping_cart h5 {
  display: none;
}
.hestia-top-bar .widget.widget_shopping_cart .widget_shopping_cart_content {
  display: inline-block;
}
.hestia-top-bar .widget.widget_shopping_cart .cart_list {
  border-radius: 0 0 6px 6px;
  opacity: 0;
  visibility: hidden;
  margin-top: -10px;
  -webkit-transition: all 0.3s ease;
  -moz-transition: all 0.3s ease;
  -ms-transition: all 0.3s ease;
  -o-transition: all 0.3s ease;
  transition: all 0.3s ease;
  padding: 0 15px 15px;
  position: absolute;
  right: 0;
  top: 40px;
  z-index: 1050;
}
.hestia-top-bar .widget.widget_shopping_cart .cart_list li {
  display: block;
  margin-top: 15px;
  padding-bottom: 0;
  white-space: nowrap;
}
.hestia-top-bar .widget.widget_shopping_cart .cart_list li a:not(.remove) {
  margin: 0;
  padding-left: 65px;
  text-align: right;
}
.hestia-top-bar .widget.widget_shopping_cart .cart_list li img {
  float: right;
  width: 50px;
  margin-right: 0;
  margin-left: 15px;
}
.hestia-top-bar .widget.widget_shopping_cart .cart_list li .quantity {
  padding-left: 65px;
}
.hestia-top-bar .widget.widget_shopping_cart .cart_list li .variation {
  display: none;
}
.hestia-top-bar .widget.widget_shopping_cart .cart_list li.empty {
  padding: 0;
}
.hestia-top-bar .widget.widget_shopping_cart .total {
  border: none;
  margin: 0;
  padding: 0;
}
.hestia-top-bar .widget.widget_shopping_cart .total strong {
  display: none;
}
.hestia-top-bar .widget.widget_shopping_cart .total .amount {
  float: none;
}

/*--------------------------------------------------------------
## Account Page
--------------------------------------------------------------*/
.woocommerce-account .woocommerce-MyAccount-navigation {
  display: inline-block;
  width: 20%;
}
.woocommerce-account .woocommerce-MyAccount-content {
  display: inline-block;
  float: left;
  width: 75%;
  margin-right: 5%;
}
.woocommerce-account .woocommerce-MyAccount-navigation ul {
  padding: 0;
  border-top: 1px solid #eee;
}
.woocommerce-account .woocommerce-MyAccount-navigation ul li {
  padding-bottom: 0;
  border-bottom: 1px solid #eee;
  list-style: none;
}
.woocommerce-account .woocommerce-MyAccount-navigation ul li.is-active a:before {
  opacity: 1;
}
.woocommerce-account .woocommerce-MyAccount-navigation ul li a {
  display: block;
  padding: 10px 5px;
}
.woocommerce-account .woocommerce-MyAccount-navigation ul li a:hover {
  color: #333;
}
.woocommerce-account .woocommerce-MyAccount-navigation ul li a:before {
  margin-left: 20px;
  opacity: 0.25;
}
.woocommerce-account .woocommerce-MyAccount-navigation ul li a:hover:before {
  opacity: 1;
}
.woocommerce-account .woocommerce-MyAccount-navigation ul li.woocommerce-MyAccount-navigation-link--dashboard a:before, .woocommerce-account .woocommerce-MyAccount-navigation ul li.woocommerce-MyAccount-navigation-link--orders a:before, .woocommerce-account .woocommerce-MyAccount-navigation ul li.woocommerce-MyAccount-navigation-link--downloads a:before, .woocommerce-account .woocommerce-MyAccount-navigation ul li.woocommerce-MyAccount-navigation-link--edit-address a:before, .woocommerce-account .woocommerce-MyAccount-navigation ul li.woocommerce-MyAccount-navigation-link--payment-methods a:before, .woocommerce-account .woocommerce-MyAccount-navigation ul li.woocommerce-MyAccount-navigation-link--edit-account a:before, .woocommerce-account .woocommerce-MyAccount-navigation ul li.woocommerce-MyAccount-navigation-link--customer-logout a:before {
  font-family: "Font Awesome 5 Free";
  font-weight: 900;
  width: 25px;
  display: inline-block;
}
.woocommerce-account .woocommerce-MyAccount-navigation ul li.woocommerce-MyAccount-navigation-link--dashboard a:before {
  content: "\f3fd";
}
.woocommerce-account .woocommerce-MyAccount-navigation ul li.woocommerce-MyAccount-navigation-link--orders a:before {
  content: "\f291";
}
.woocommerce-account .woocommerce-MyAccount-navigation ul li.woocommerce-MyAccount-navigation-link--downloads a:before {
  content: "\f1c6";
}
.woocommerce-account .woocommerce-MyAccount-navigation ul li.woocommerce-MyAccount-navigation-link--edit-address a:before {
  content: "\f015";
}
.woocommerce-account .woocommerce-MyAccount-navigation ul li.woocommerce-MyAccount-navigation-link--payment-methods a:before {
  content: "\f09d";
}
.woocommerce-account .woocommerce-MyAccount-navigation ul li.woocommerce-MyAccount-navigation-link--edit-account a:before {
  content: "\f007";
}
.woocommerce-account .woocommerce-MyAccount-navigation ul li.woocommerce-MyAccount-navigation-link--customer-logout a:before {
  content: "\f2f5";
}
.woocommerce-account .woocommerce-MyAccount-content h2 {
  text-align: center;
}
.woocommerce-account p.order-again {
  text-align: left;
}

.woocommerce-EditAccountForm input[type="submit"] {
  float: left;
  margin-top: 50px;
}

.woocommerce-account table.shop_table_responsive thead {
  color: #fff;
  background-color: #333;
}
.woocommerce-account table.shop_table_responsive thead th {
  padding: 10px;
  border-left: 1px solid;
  text-align: center;
}
.woocommerce-account table.shop_table_responsive tbody td {
  padding: 10px;
  text-align: center;
}
.woocommerce-account table.shop_table_responsive tbody tr {
  border-bottom: 1px solid #eee;
}
.woocommerce-account .my_account_orders .button {
  text-decoration: underline;
  text-transform: uppercase;
}
.woocommerce-account .woocommerce-MyAccount-content .col2-set {
  width: 100%;
}

/* Orders tab */
.woocommerce-account.woocommerce-orders .woocommerce-message.woocommerce-info a.woocommerce-Button.button {
  color: #3C4858;
}

.woocommerce-account.woocommerce-orders .woocommerce-message.woocommerce-info:before {
  color: #3C4858;
}

/* Downloads tab */
.woocommerce-account.woocommerce-downloads .woocommerce .woocommerce-Message.woocommerce-info:not(.woocommerce-message) a.button {
  color: #ffffff;
}

/*--------------------------------------------------------------
## Notifications
--------------------------------------------------------------*/
.woocommerce-info,
.woocommerce-error,
.woocommerce-message {
  padding: 20px 50px 20px 15px !important;
  border: none;
  color: #fff;
  background: #efefef;
}
.woocommerce-info:before,
.woocommerce-error:before,
.woocommerce-message:before {
  top: 19px;
  color: #3C4858;
  font-family: "Font Awesome 5 Free";
  font-weight: 900;
}
.woocommerce-info > a.button,
.woocommerce-error > a.button,
.woocommerce-message > a.button {
  background-color: transparent;
  box-shadow: none;
  padding: 5px 10px 0;
  color: #3C4858;
}
.woocommerce-info > a.button:hover,
.woocommerce-error > a.button:hover,
.woocommerce-message > a.button:hover {
  color: #3C4858;
  background: none;
  box-shadow: none;
  opacity: .75;
}

.woocommerce-info {
  color: #fff;
  background-color: #00bcd4;
}
.woocommerce-info:before {
  color: #fff;
  content: "";
  display: inline-block;
  background-image: url(data:image/svg+xml;base64,PHN2ZyBhcmlhLWhpZGRlbj0idHJ1ZSIgZm9jdXNhYmxlPSJmYWxzZSIgZGF0YS1wcmVmaXg9ImZhcyIgZGF0YS1pY29uPSJpbmZvIiBjbGFzcz0ic3ZnLWlubGluZS0tZmEgZmEtaW5mbyBmYS13LTYiIHJvbGU9ImltZyIgeG1sbnM9Imh0dHA6Ly93d3cudzMub3JnLzIwMDAvc3ZnIiB2aWV3Qm94PSIwIDAgMTkyIDUxMiI+PHBhdGggZmlsbD0iI2ZmZmZmZiIgZD0iTTIwIDQyNC4yMjloMjBWMjc5Ljc3MUgyMGMtMTEuMDQ2IDAtMjAtOC45NTQtMjAtMjBWMjEyYzAtMTEuMDQ2IDguOTU0LTIwIDIwLTIwaDExMmMxMS4wNDYgMCAyMCA4Ljk1NCAyMCAyMHYyMTIuMjI5aDIwYzExLjA0NiAwIDIwIDguOTU0IDIwIDIwVjQ5MmMwIDExLjA0Ni04Ljk1NCAyMC0yMCAyMEgyMGMtMTEuMDQ2IDAtMjAtOC45NTQtMjAtMjB2LTQ3Ljc3MWMwLTExLjA0NiA4Ljk1NC0yMCAyMC0yMHpNOTYgMEM1Ni4yMzUgMCAyNCAzMi4yMzUgMjQgNzJzMzIuMjM1IDcyIDcyIDcyIDcyLTMyLjIzNSA3Mi03MlMxMzUuNzY0IDAgOTYgMHoiPjwvcGF0aD48L3N2Zz4=);
  width: 5.25px;
  height: 22px;
  background-size: 5.25px;
  background-repeat: no-repeat;
  background-position: center;
}
.woocommerce-info a {
  color: #fff;
}
.woocommerce-info a:hover {
  opacity: .75;
  color: #fff;
}

.woocommerce-error {
  background-color: #fccbc7;
  color: #3C4858;
}
.woocommerce-error:before {
  content: "\f12a";
}

.woocommerce-message {
  background-color: #e5ffe8;
  color: #3C4858;
}
.woocommerce-message a:not(.button) {
  color: #3C4858;
}
.woocommerce-message a:not(.button):hover {
  opacity: .75;
}
.woocommerce-message:before {
  content: "\f00c";
}

/*--------------------------------------------------------------
## Reviews
--------------------------------------------------------------*/
.woocommerce #reviews #comments ol.commentlist {
  padding: 0;
}
.woocommerce div.product #reviews .comment img {
  overflow: hidden;
  width: 45px;
  height: 45px;
  margin: 0 auto;
  padding: 0;
  border: none;
  border-radius: 50%;
  -webkit-box-shadow: 0 6px 10px 0 rgba(0, 0, 0, 0.14), 0 1px 18px 0 rgba(0, 0, 0, 0.12), 0 3px 5px -1px rgba(0, 0, 0, 0.2);
  box-shadow: 0 6px 10px 0 rgba(0, 0, 0, 0.14), 0 1px 18px 0 rgba(0, 0, 0, 0.12), 0 3px 5px -1px rgba(0, 0, 0, 0.2);
}
.woocommerce #reviews #comments ol.commentlist li img.avatar {
  overflow: hidden;
  width: 45px;
  height: 45px;
  margin: 0 auto;
  padding: 0;
  border: none;
  border-radius: 50%;
  -webkit-box-shadow: 0 6px 10px 0 rgba(0, 0, 0, 0.14), 0 1px 18px 0 rgba(0, 0, 0, 0.12), 0 3px 5px -1px rgba(0, 0, 0, 0.2);
  box-shadow: 0 6px 10px 0 rgba(0, 0, 0, 0.14), 0 1px 18px 0 rgba(0, 0, 0, 0.12), 0 3px 5px -1px rgba(0, 0, 0, 0.2);
}
.woocommerce #reviews #comments ol.commentlist li .comment-text {
  margin-bottom: 25px;
  border: none;
}
.woocommerce .comment-form .comment-notes {
  display: none;
}
.woocommerce .comment-reply-title {
  font-family: "Roboto Slab", "Times New Roman", serif;
  color: #3C4858;
  text-decoration: none;
  word-wrap: break-word;
  margin: 20px 0 10px;
  text-align: center;
  display: block;
}
.woocommerce .form-submit {
  text-align: left;
}

/*--------------------------------------------------------------
## Cart
--------------------------------------------------------------*/
.woocommerce-page.woocommerce-cart .cross-sells h2 {
  margin-bottom: 30px;
}

@media (min-width: 992px) {
  .woocommerce-page.woocommerce-cart ul.products > li.product {
    text-align: right;
    padding: 0;
  }
}
@media (min-width: 768px) and (max-width: 991px) {
  .woocommerce-page.woocommerce-cart .cross-sells h2 {
    text-align: center;
  }
}
@media (max-width: 767px) {
  .woocommerce-page.woocommerce-cart .cross-sells h2 {
    text-align: center;
  }
}
/*--------------------------------------------------------------
## Checkout
--------------------------------------------------------------*/
/* Kepp the navbar with the logo when Distraction free option is enabled */
@media (min-width: 769px) {
  .woocommerce-checkout .navbar:not(.full-screen-menu).navbar-scroll-point.hestia_center .navbar-header .title-logo-wrapper {
    display: block !important;
  }
}
.hestia-checkout-no-distraction .title-logo-wrapper {
  pointer-events: none;
}

.woocommerce .col2-set,
.woocommerce-page .col2-set,
.woocommerce-checkout .col2-set {
  float: right;
  width: 48%;
  margin-left: 12%;
}

.woocommerce-account .col2-set {
  width: 100%;
}

.woocommerce-checkout .col2-set {
  margin-bottom: 50px;
}

#customer_details .col-1,
#customer_details .col-2 {
  clear: right;
  width: 100%;
}

#order_review {
  float: left;
  clear: left;
  width: 40%;
  margin-left: 0;
}

.woocommerce-checkout table.shop_table td strong {
  display: block;
}
.woocommerce-checkout .woocommerce-info,
.woocommerce-checkout .woocommerce-error,
.woocommerce-checkout .woocommerce-message,
.woocommerce-checkout #payment {
  border-radius: 3px;
}
.woocommerce-checkout #payment {
  background: #f0f0f0;
}
.woocommerce-checkout #payment #place_order {
  float: none;
}
.woocommerce-checkout #payment ul.payment_methods,
.woocommerce-checkout #payment div.form-row {
  padding: 20px;
}
.woocommerce-checkout #payment ul.payment_methods {
  border: none;
}
.woocommerce-checkout #payment ul.payment_methods li {
  background: #f0f0f0;
}
.woocommerce-checkout #payment ul.payment_methods li:last-child div.payment_box {
  margin-bottom: 0;
}
.woocommerce-checkout #payment div.payment_box {
  background: #dfdfdf;
}
.woocommerce-checkout #payment div.payment_box ::before {
  border-color: #dfdfdf;
}
.woocommerce-checkout #payment .payment_method_paypal .about_paypal {
  float: none;
  margin-right: 10px;
}
.woocommerce-checkout .checkout_coupon .form-row {
  margin-bottom: 0;
  width: 53%;
}
.woocommerce-checkout .checkout_coupon .form-row-last {
  text-align: left;
  width: 47%;
}
.woocommerce-checkout .form-row label {
  color: #3C4858;
}
.woocommerce-checkout .select2-container--default .select2-selection--single,
.woocommerce-checkout .select2-dropdown {
  border-color: #d2d2d2;
}
.woocommerce-checkout .woocommerce-checkout-payment .form-row .woocommerce-form__label-for-checkbox, .woocommerce-checkout .woocommerce-checkout-payment li > label {
  color: #2d3359;
}
.woocommerce-checkout .woocommerce-checkout-payment .form-row .woocommerce-form__label-for-checkbox span:not(.required), .woocommerce-checkout .woocommerce-checkout-payment li > label span:not(.required) {
  padding-right: 20px;
}
.woocommerce-checkout .woocommerce-checkout-payment .form-row .woocommerce-form__label-for-checkbox input, .woocommerce-checkout .woocommerce-checkout-payment li > label input {
  margin: 7px 0 0;
}
.woocommerce-checkout .woocommerce-checkout-payment input[type="checkbox"] {
  position: relative;
  margin: 0px;
}
.woocommerce-checkout .woocommerce-account-fields p.create-account {
  margin: 0;
}
.woocommerce-checkout .woocommerce-shipping-fields h3 {
  margin: 0;
  padding-right: 3px;
}
.woocommerce-checkout .woocommerce-shipping-fields h3 label {
  margin: 0 0 10px;
}
.woocommerce-checkout .woocommerce-shipping-fields h3 label input {
  margin-right: 0;
  position: relative;
}
.woocommerce-checkout .woocommerce-shipping-fields h3 label span {
  color: #999999;
}
.woocommerce-checkout .shop_table tr.shipping td p {
  margin: 0;
}
.woocommerce-checkout #ship-to-different-address {
  margin-bottom: 30px;
}
.woocommerce-checkout #ship-to-different-address #ship-to-different-address-checkbox {
  float: right;
  margin: 0;
}
.woocommerce-checkout #ship-to-different-address span {
  float: right;
  margin-right: 7px;
}

/*--------------------------------------------------------------
## WooCommerce Responsive
--------------------------------------------------------------*/
@media (max-width: 1200px) {
  .woocommerce.archive .blog-post .col-md-12 {
    padding-right: 15px;
    padding-left: 15px;
  }
}
@media (max-width: 991px) {
  .woocommerce .content-sidebar-left,
  .woocommerce .content-sidebar-right {
    padding: 0 15px;
  }
  .woocommerce .before-shop-main {
    padding-right: 15px;
    padding-left: 15px;
    margin: 20px 0 25px;
  }
  .woocommerce .page-header .container .row .cart-contents-content {
    left: 30px;
  }

  .single-product .page-header .container .row .cart-contents-content {
    left: 15px;
  }

  /* product list */
  .woocommerce-ordering,
  .woocommerce-ordering select {
    margin-left: 0;
  }

  .woocommerce-breadcrumb {
    width: 100%;
    margin-bottom: 20px;
  }

  /*My Account Styling*/
  .woocommerce-account .woocommerce-MyAccount-navigation {
    width: 100%;
  }

  .woocommerce-account .woocommerce-MyAccount-navigation ul li {
    display: table-cell;
    border: none;
  }

  .woocommerce-account .woocommerce-MyAccount-navigation ul {
    display: table;
    width: 100%;
    margin: 0 0 25px;
    border: none;
  }

  .woocommerce-account .woocommerce-MyAccount-navigation ul li a {
    display: block;
  }

  .woocommerce-account .woocommerce-MyAccount-content {
    width: 100%;
    margin-right: 0;
  }

  .woocommerce-account .woocommerce-MyAccount-navigation ul li a:before {
    margin-left: 5px;
    opacity: 0.25;
  }

  .woocommerce-account input.woocommerce-Button.button {
    height: auto;
    margin-top: 10px;
    padding: 8px 37px;
    border: none;
    color: #fff;
    font-family: "Roboto Condensed", sans-serif;
    letter-spacing: 2px;
    text-transform: uppercase;
  }

  .woocommerce-account input.woocommerce-Button.button:hover {
    background: rgba(17, 17, 17, 0.8);
  }

  .woocommerce-checkout table.shop_table th.product-total,
  .woocommerce-checkout table.shop_table td.product-total,
  .woocommerce-checkout table.shop_table tfoot td {
    text-align: left;
  }

  .woocommerce.single-product .product .images {
    margin-bottom: 30px;
  }
  .woocommerce.single-product .product form.cart {
    margin-top: 30px;
  }
  .woocommerce.single-product .related.products,
  .woocommerce.single-product .exclusive-products {
    padding-bottom: 0;
  }
  .woocommerce.single-product .related.products h2,
  .woocommerce.single-product .exclusive-products h2 {
    margin-bottom: 35px;
  }
  .woocommerce.single-product .upsells.products {
    padding-bottom: 0;
  }
  .woocommerce.single-product .upsells.products h2 {
    margin-bottom: 20px;
  }

  .woocommerce-cart .blog-post .woocommerce .woocommerce-cart-form {
    float: right;
    width: 100%;
  }
  .woocommerce-cart .blog-post .woocommerce .cart-collaterals {
    float: right;
    margin-top: 0px;
    width: 100%;
  }
  .woocommerce-cart .blog-post .woocommerce .cart-collaterals .cart_totals {
    width: 100%;
  }
  .woocommerce-cart table.shop_table_responsive tr:nth-child(2n) td {
    background: transparent;
  }
}
@media (max-width: 768px) {
  .woocommerce.single-product .product .images, .woocommerce.single-product .product .summary {
    width: 100%;
  }

  .woocommerce.single-product .product .summary {
    padding-right: 0;
  }

  .woocommerce.single-product .related ul.products {
    margin: 0;
  }

  .woocommerce-product-search input.search-field {
    width: 85%;
  }

  .nav-cart.responsive-nav-cart {
    display: inline-block;
  }

  .admin-bar.woocommerce-cart .blog-post, .admin-bar.woocommerce-checkout .blog-post {
    padding-top: 0;
  }

  .woocommerce-cart .blog-post {
    padding-top: 40px;
  }
  .woocommerce-cart .wrapper.no-content .page-header, .woocommerce-cart .wrapper.classic-blog .page-header {
    display: none;
  }
  .woocommerce-cart .section {
    padding: 30px 0 0;
  }
  .woocommerce-cart .section.section-blog-info:empty {
    padding: 0;
  }
  .woocommerce-cart table.cart td.actions {
    background: none !important;
  }
  .woocommerce-cart table.shop_table td.product-name dl.variation dd,
  .woocommerce-cart table.shop_table td.product-name dl.variation dt {
    margin-bottom: 0;
  }
  .woocommerce-cart table.shop_table td.product-remove {
    float: left;
    position: relative;
    top: 5px;
    width: auto;
    border-top: none;
  }
  .woocommerce-cart .cart-collaterals {
    margin-bottom: 0;
  }
  .woocommerce-cart .wc-proceed-to-checkout {
    padding: 1em 0 0;
  }

  .woocommerce-checkout .blog-post {
    padding-top: 40px;
  }
  .woocommerce-checkout .wrapper.no-content .page-header, .woocommerce-checkout .wrapper.classic-blog .page-header {
    display: none;
  }
  .woocommerce-checkout .section {
    padding: 20px 0 0;
  }
  .woocommerce-checkout .woocommerce-billing-fields h3 {
    margin-top: 0;
  }
  .woocommerce-checkout td.product-name dl.variation dt,
  .woocommerce-checkout td.product-name dl.variation dd {
    margin-bottom: 0;
  }
}
@media (max-width: 767px) {
  /* Woocommerce */
  .woocommerce .page-header .container {
    padding-top: 170px;
  }

  .woocommerce-page.woocommerce-cart ul.products li.product {
    max-width: 370px;
    width: 100%;
  }

  .woocommerce .page-header {
    min-height: 200px;
  }
  .woocommerce .page-header .container .row .cart-contents-content {
    left: 10px;
  }

  .single-product .page-header .container .row .cart-contents-content {
    left: 15px;
  }

  /*My Account Styling*/
  .woocommerce-account .woocommerce-MyAccount-navigation ul li {
    display: inline-block;
    min-width: 125px;
    border: none;
  }

  .woocommerce-account .woocommerce-MyAccount-navigation ul {
    display: table;
    width: 100%;
    margin: 0 0 25px;
    border: none;
  }

  .woocommerce .col2-set, .woocommerce-page .col2-set {
    width: auto;
    float: none;
    margin-left: 0;
  }

  #order_review, #order_review_heading {
    float: none;
    width: auto;
  }

  .woocommerce.single-product .product .images,
  .woocommerce.single-product .product .summary,
  .woocommerce.single-product .product .hestia-product-image-wrap {
    width: 100%;
    position: relative;
    clear: both;
  }
  .woocommerce.single-product .product .summary {
    padding-right: 0;
  }
  .woocommerce.single-product .product span.onsale {
    right: -5px;
    top: -5px;
  }
  .woocommerce.single-product.header-layout-classic-blog .blog-post .col-md-12 {
    padding: 0;
  }
  .woocommerce.single-product.header-layout-classic-blog .blog-post .col-md-12 > div[id^=product].product {
    padding: 30px 15px 30px 15px;
  }
  .woocommerce.single-product .blog-post .col-md-12 {
    padding: 0;
  }
  .woocommerce.single-product .blog-post .col-md-12 > div[id^=product].product {
    padding: 99px 15px 30px 15px;
    border-radius: 0;
    margin-top: 0;
  }
  .woocommerce.single-product .page-header {
    display: none;
  }
  .woocommerce.single-product.admin-bar .navbar.navbar.navbar-not-transparent.header-with-topbar {
    top: 40px;
  }

  .woocommerce.single-product.single .section {
    padding: 0;
  }

  .woocommerce .cart-collaterals {
    margin-top: 0;
  }
  .woocommerce .cart-collaterals h2 {
    margin-top: 20px;
    margin-bottom: 10px;
    text-align: center;
  }
  .woocommerce .cart-collaterals .cross-sells,
  .woocommerce .cart-collaterals .cart_totals,
  .woocommerce .cart-collaterals .cross-sells ul.products li {
    width: 100%;
  }
}
@media (min-width: 768px) {
  .woocommerce.single-product.admin-bar .navbar.navbar-not-transparent.header-with-topbar {
    margin-top: 0;
  }
  .woocommerce.single-product.admin-bar .navbar.navbar-not-transparent.header-with-topbar.navbar-scroll-point {
    top: 32px;
  }
}
@media (max-width: 1200px) {
  .woocommerce .widget_shopping_cart_content a.button {
    padding: 12px 18px;
  }

  .woocommerce-cart .col-md-12,
  .woocommerce-checkout .col-md-12 {
    padding-right: 15px;
    padding-left: 15px;
  }
}
@media (max-width: 600px) {
  .woocommerce.single-product.admin-bar .navbar.navbar.navbar-not-transparent {
    top: 0;
  }
  .woocommerce.single-product.admin-bar .navbar.navbar.navbar-not-transparent.header-with-topbar {
    top: 40px;
  }
  .woocommerce.single-product.admin-bar .navbar.navbar.navbar-not-transparent.header-with-topbar.navbar-scroll-point {
    top: 0;
  }
}
@media (max-width: 480px) {
  /*My Account Styling*/
  .woocommerce-account .woocommerce-MyAccount-navigation ul li {
    width: 50%;
  }

  .woocommerce-account .my_account_orders .button {
    display: block;
  }

  .woocommerce span.onsale {
    right: -5px;
    top: -5px;
  }

  .woocommerce-product-search input.search-field {
    width: 70%;
  }

  .woocommerce.single-product .woocommerce-message {
    position: relative;
    padding: 20px 50px 40px 15px !important;
  }
  .woocommerce.single-product .woocommerce-message a {
    float: right;
    position: absolute;
    bottom: 20px;
    padding: 0;
  }
  .woocommerce.single-product #review_form #respond p.form-submit {
    text-align: center;
  }
  .woocommerce div.product .woocommerce-tabs ul.tabs {
    margin-bottom: 30px;
  }
  .woocommerce div.product .woocommerce-tabs ul.tabs li {
    display: block;
    padding: 0;
  }
  .woocommerce div.product .woocommerce-tabs ul.tabs li a {
    display: block;
    text-align: right !important;
    margin-bottom: 5px;
  }

  .woocommerce-cart table.cart td.actions .coupon .input-text {
    margin: 0 0 10px 0;
    width: 100%;
  }
  .woocommerce-cart table.cart td.actions .coupon .button {
    width: 100%;
  }

  .woocommerce-checkout .checkout_coupon .form-row,
  .woocommerce-checkout .checkout_coupon input.button {
    width: 100%;
  }
  .woocommerce-checkout .checkout_coupon .input-text {
    margin-bottom: 10px !important;
  }

  .woocommerce .woocommerce-ordering,
  .woocommerce-page .woocommerce-ordering {
    float: none;
  }
  .woocommerce .woocommerce-ordering select,
  .woocommerce-page .woocommerce-ordering select {
    letter-spacing: -0.025em;
  }

  .woocommerce .col-xs-9 .woocommerce-ordering,
  .woocommerce-page .col-xs-9 .woocommerce-ordering {
    text-align: left;
  }

  .woocommerce .col-xs-12 .woocommerce-ordering,
  .woocommerce-page .col-xs-12 .woocommerce-ordering {
    text-align: right;
  }
  .woocommerce .col-xs-12 .woocommerce-ordering select,
  .woocommerce-page .col-xs-12 .woocommerce-ordering select {
    width: 100%;
  }
}
/*--------------------------------------------------------------
## Shop Grid
--------------------------------------------------------------*/
/**
 * Shop Grid
 * Products Grid on any page where WooCommerce shortcode is used, including the Shop page
 *
 * Why is this file here and not in 6_woocommerce folder
 * It's because woocommerce CSS it's loaded only on WC pages and front page
 * This approach should work on any page where a WooCommerce shortcode is used
 */
.woocommerce ul.products:before {
  display: none !important;
}
.woocommerce ul.products.columns-6,
.woocommerce ul.products.columns-5,
.woocommerce ul.products.columns-4,
.woocommerce ul.products.columns-3,
.woocommerce ul.products.columns-2,
.woocommerce ul.products.columns-1 {
  display: grid;
}
.woocommerce ul.products.columns-6 li.product,
.woocommerce ul.products.columns-5 li.product,
.woocommerce ul.products.columns-4 li.product,
.woocommerce ul.products.columns-3 li.product,
.woocommerce ul.products.columns-2 li.product,
.woocommerce ul.products.columns-1 li.product {
  width: auto;
  min-width: 0;
  margin: 0;
}
.woocommerce ul.products.columns-6 li.product-category,
.woocommerce ul.products.columns-5 li.product-category,
.woocommerce ul.products.columns-4 li.product-category,
.woocommerce ul.products.columns-3 li.product-category,
.woocommerce ul.products.columns-2 li.product-category,
.woocommerce ul.products.columns-1 li.product-category {
  text-align: center;
}

@media (min-width: 992px) {
  .woocommerce {
    /* Compatibility with left and right sidebar on archive page */
  }
  .woocommerce .products.columns-6 {
    grid-template-columns: repeat(6, 1fr);
  }
  .woocommerce .products.columns-5 {
    grid-template-columns: repeat(5, 1fr);
  }
  .woocommerce .products.columns-4 {
    grid-template-columns: repeat(4, 1fr);
  }
  .woocommerce .products.columns-3 {
    grid-template-columns: repeat(3, 1fr);
  }
  .woocommerce .products.columns-2 {
    grid-template-columns: repeat(2, 1fr);
  }
  .woocommerce .products.columns-1 {
    grid-template-columns: 1fr;
  }
  .woocommerce .products.columns-1 li.product-category {
    margin: 30px auto 0 !important;
  }
  .woocommerce .products.columns-2 li.product-category > a > img,
  .woocommerce .products.columns-1 li.product-category > a > img {
    max-width: 230px;
  }
  .woocommerce .products.columns-2 li.product,
  .woocommerce .products.columns-1 li.product {
    text-align: center;
  }
  .woocommerce .products.columns-2 li.product .card-product,
  .woocommerce .products.columns-1 li.product .card-product {
    width: auto;
  }
  .woocommerce .products.columns-2 li.product .card-product .card-image > a > img,
  .woocommerce .products.columns-1 li.product .card-product .card-image > a > img {
    max-width: 230px;
  }
  .woocommerce .products.columns-2 li.product .card-product .content,
  .woocommerce .products.columns-1 li.product .card-product .content {
    max-width: 230px;
    margin-right: auto;
    margin-left: auto;
    padding: 15px;
  }
  .woocommerce .content-sidebar-left .products.columns-6,
  .woocommerce .content-sidebar-left .products.columns-5,
  .woocommerce .content-sidebar-right .products.columns-6,
  .woocommerce .content-sidebar-right .products.columns-5 {
    grid-template-columns: repeat(4, 1fr);
  }
}
@media (max-width: 991px) {
  .woocommerce {
    /* Compatibility with left and right sidebar on archive page */
  }
  .woocommerce .products.columns-6,
  .woocommerce .products.columns-5,
  .woocommerce .products.columns-4,
  .woocommerce .products.columns-3,
  .woocommerce .products.columns-2 {
    grid-template-columns: repeat(2, 1fr);
  }
  .woocommerce .products.columns-2 li.product-category {
    margin: 30px auto 30px;
  }
  .woocommerce .products.columns-1 {
    grid-template-columns: 1fr;
  }
  .woocommerce .products.columns-1 li {
    margin: 25px auto;
  }
  .woocommerce .products.columns-1 li.product-category {
    margin: 55px auto 25px;
  }
  .woocommerce .products.columns-6 li.product-category > a > img,
  .woocommerce .products.columns-5 li.product-category > a > img,
  .woocommerce .products.columns-4 li.product-category > a > img,
  .woocommerce .products.columns-3 li.product-category > a > img,
  .woocommerce .products.columns-2 li.product-category > a > img,
  .woocommerce .products.columns-1 li.product-category > a > img {
    max-width: 230px;
  }
  .woocommerce .products.columns-6 li.product,
  .woocommerce .products.columns-5 li.product,
  .woocommerce .products.columns-4 li.product,
  .woocommerce .products.columns-3 li.product,
  .woocommerce .products.columns-2 li.product,
  .woocommerce .products.columns-1 li.product {
    text-align: center;
  }
  .woocommerce .products.columns-6 li.product .card-product,
  .woocommerce .products.columns-5 li.product .card-product,
  .woocommerce .products.columns-4 li.product .card-product,
  .woocommerce .products.columns-3 li.product .card-product,
  .woocommerce .products.columns-2 li.product .card-product,
  .woocommerce .products.columns-1 li.product .card-product {
    width: auto;
  }
  .woocommerce .products.columns-6 li.product .card-product .card-image > a > img,
  .woocommerce .products.columns-5 li.product .card-product .card-image > a > img,
  .woocommerce .products.columns-4 li.product .card-product .card-image > a > img,
  .woocommerce .products.columns-3 li.product .card-product .card-image > a > img,
  .woocommerce .products.columns-2 li.product .card-product .card-image > a > img,
  .woocommerce .products.columns-1 li.product .card-product .card-image > a > img {
    max-width: 230px;
  }
  .woocommerce .products.columns-6 li.product .card-product .content,
  .woocommerce .products.columns-5 li.product .card-product .content,
  .woocommerce .products.columns-4 li.product .card-product .content,
  .woocommerce .products.columns-3 li.product .card-product .content,
  .woocommerce .products.columns-2 li.product .card-product .content,
  .woocommerce .products.columns-1 li.product .card-product .content {
    max-width: 230px;
    margin-right: auto;
    margin-left: auto;
    padding: 15px;
  }
  .woocommerce .content-sidebar-left .products.columns-6,
  .woocommerce .content-sidebar-left .products.columns-5,
  .woocommerce .content-sidebar-right .products.columns-6,
  .woocommerce .content-sidebar-right .products.columns-5 {
    grid-template-columns: repeat(2, 1fr);
  }

  /* End of woocommerce */
}
/* End of media query */
@media (max-width: 767px) {
  .woocommerce {
    /* Compatibility with left and right sidebar on archive page */
  }
  .woocommerce .products[class*="columns-"] {
    grid-template-columns: 1fr;
  }
  .woocommerce .products[class*="columns-"] li {
    margin: 20px auto 1px !important;
  }
  .woocommerce .products[class*="columns-"] li.product-category {
    margin: 50px auto 1px !important;
  }
  .woocommerce .content-sidebar-left .products.columns-6,
  .woocommerce .content-sidebar-left .products.columns-5,
  .woocommerce .content-sidebar-right .products.columns-6,
  .woocommerce .content-sidebar-right .products.columns-5 {
    grid-template-columns: 1fr;
  }

  /* End of woocommerce */
}
/* End of media query */
/* Compatibility with Internet Explorer */
@supports not (display: grid) {
  @media (min-width: 992px) {
    .woocommerce ul.products.columns-6,
    .woocommerce ul.products.columns-5,
    .woocommerce ul.products.columns-4,
    .woocommerce ul.products.columns-3,
    .woocommerce ul.products.columns-2,
    .woocommerce ul.products.columns-1 {
      display: block;
      -ms-grid-columns: none;
    }
    .woocommerce .content-full ul.products.columns-4 li.product,
    .woocommerce .content-sidebar-left ul.products.columns-4 li.product,
    .woocommerce .content-sidebar-right ul.products.columns-4 li.product {
      width: 25%;
    }
    .woocommerce .content-full ul.products.columns-3 li.product,
    .woocommerce .content-sidebar-left ul.products.columns-3 li.product,
    .woocommerce .content-sidebar-right ul.products.columns-3 li.product {
      width: 33.33%;
    }
    .woocommerce .content-full ul.products.columns-2 li.product,
    .woocommerce .content-sidebar-left ul.products.columns-2 li.product,
    .woocommerce .content-sidebar-right ul.products.columns-2 li.product {
      width: 50%;
    }
    .woocommerce .content-full ul.products.columns-1 li.product,
    .woocommerce .content-sidebar-left ul.products.columns-1 li.product,
    .woocommerce .content-sidebar-right ul.products.columns-1 li.product {
      width: 100%;
    }
    .woocommerce .content-full ul.products.columns-6 li.product {
      width: 16.66%;
    }
    .woocommerce .content-full ul.products.columns-5 li.product {
      width: 20%;
    }
    .woocommerce .content-sidebar-left ul.products.columns-6 li.product,
    .woocommerce .content-sidebar-left ul.products.columns-5 li.product,
    .woocommerce .content-sidebar-right ul.products.columns-6 li.product,
    .woocommerce .content-sidebar-right ul.products.columns-5 li.product {
      width: 25%;
    }
    .woocommerce .content-sidebar-left ul.products.columns-6 li.first,
    .woocommerce .content-sidebar-left ul.products.columns-5 li.first,
    .woocommerce .content-sidebar-right ul.products.columns-6 li.first,
    .woocommerce .content-sidebar-right ul.products.columns-5 li.first {
      clear: none;
    }

    .woocommerce.single-product ul.products {
      display: block;
    }
    .woocommerce.single-product ul.products li.product {
      width: 25%;
    }

    .woocommerce-cart ul.products {
      display: block;
    }
    .woocommerce-cart ul.products li.product {
      width: 50%;
    }
  }
  @media (max-width: 991px) {
    .woocommerce ul.products.columns-6,
    .woocommerce ul.products.columns-5,
    .woocommerce ul.products.columns-4,
    .woocommerce ul.products.columns-3,
    .woocommerce ul.products.columns-2,
    .woocommerce ul.products.columns-1 {
      display: block;
    }
    .woocommerce ul.products.columns-6 li.first,
    .woocommerce ul.products.columns-6 li.last,
    .woocommerce ul.products.columns-5 li.first,
    .woocommerce ul.products.columns-5 li.last,
    .woocommerce ul.products.columns-4 li.first,
    .woocommerce ul.products.columns-4 li.last,
    .woocommerce ul.products.columns-3 li.first,
    .woocommerce ul.products.columns-3 li.last,
    .woocommerce ul.products.columns-2 li.first,
    .woocommerce ul.products.columns-2 li.last,
    .woocommerce ul.products.columns-1 li.first,
    .woocommerce ul.products.columns-1 li.last {
      clear: none;
    }
    .woocommerce ul.products.columns-6 li.product,
    .woocommerce ul.products.columns-5 li.product,
    .woocommerce ul.products.columns-4 li.product,
    .woocommerce ul.products.columns-3 li.product,
    .woocommerce ul.products.columns-2 li.product {
      width: 50%;
    }
    .woocommerce ul.products.columns-1 li.product {
      width: 100%;
    }

    .woocommerce-cart ul.products,
    .woocommerce.single-product ul.products {
      display: block;
    }
    .woocommerce-cart ul.products li.product,
    .woocommerce.single-product ul.products li.product {
      width: 50%;
    }
  }
  @media (max-width: 767px) {
    .woocommerce ul.products.columns-6 li.product,
    .woocommerce ul.products.columns-5 li.product,
    .woocommerce ul.products.columns-4 li.product,
    .woocommerce ul.products.columns-3 li.product,
    .woocommerce ul.products.columns-2 li.product,
    .woocommerce ul.products.columns-1 li.product {
      width: 100%;
    }

    .woocommerce-cart ul.products,
    .woocommerce.single-product ul.products {
      display: block;
    }
    .woocommerce-cart ul.products li.product,
    .woocommerce.single-product ul.products li.product {
      width: 100%;
    }
  }
}
@media (min-width: 992px) and (-ms-high-contrast: active), (min-width: 992px) and (-ms-high-contrast: none) {
  .woocommerce ul.products.columns-6,
  .woocommerce ul.products.columns-5,
  .woocommerce ul.products.columns-4,
  .woocommerce ul.products.columns-3,
  .woocommerce ul.products.columns-2,
  .woocommerce ul.products.columns-1 {
    display: block;
    -ms-grid-columns: none;
  }
  .woocommerce .content-full ul.products.columns-4 li.product,
  .woocommerce .content-sidebar-left ul.products.columns-4 li.product,
  .woocommerce .content-sidebar-right ul.products.columns-4 li.product {
    width: 25%;
  }
  .woocommerce .content-full ul.products.columns-3 li.product,
  .woocommerce .content-sidebar-left ul.products.columns-3 li.product,
  .woocommerce .content-sidebar-right ul.products.columns-3 li.product {
    width: 33.33%;
  }
  .woocommerce .content-full ul.products.columns-2 li.product,
  .woocommerce .content-sidebar-left ul.products.columns-2 li.product,
  .woocommerce .content-sidebar-right ul.products.columns-2 li.product {
    width: 50%;
  }
  .woocommerce .content-full ul.products.columns-1 li.product,
  .woocommerce .content-sidebar-left ul.products.columns-1 li.product,
  .woocommerce .content-sidebar-right ul.products.columns-1 li.product {
    width: 100%;
  }
  .woocommerce .content-full ul.products.columns-6 li.product {
    width: 16.66%;
  }
  .woocommerce .content-full ul.products.columns-5 li.product {
    width: 20%;
  }
  .woocommerce .content-sidebar-left ul.products.columns-6 li.product,
  .woocommerce .content-sidebar-left ul.products.columns-5 li.product,
  .woocommerce .content-sidebar-right ul.products.columns-6 li.product,
  .woocommerce .content-sidebar-right ul.products.columns-5 li.product {
    width: 25%;
  }
  .woocommerce .content-sidebar-left ul.products.columns-6 li.first,
  .woocommerce .content-sidebar-left ul.products.columns-5 li.first,
  .woocommerce .content-sidebar-right ul.products.columns-6 li.first,
  .woocommerce .content-sidebar-right ul.products.columns-5 li.first {
    clear: none;
  }

  .woocommerce.single-product ul.products {
    display: block;
  }
  .woocommerce.single-product ul.products li.product {
    width: 25%;
  }

  .woocommerce-cart ul.products {
    display: block;
  }
  .woocommerce-cart ul.products li.product {
    width: 50%;
  }
}
@media (max-width: 991px) and (-ms-high-contrast: active), (max-width: 991px) and (-ms-high-contrast: none) {
  .woocommerce ul.products.columns-6,
  .woocommerce ul.products.columns-5,
  .woocommerce ul.products.columns-4,
  .woocommerce ul.products.columns-3,
  .woocommerce ul.products.columns-2,
  .woocommerce ul.products.columns-1 {
    display: block;
  }
  .woocommerce ul.products.columns-6 li.first,
  .woocommerce ul.products.columns-6 li.last,
  .woocommerce ul.products.columns-5 li.first,
  .woocommerce ul.products.columns-5 li.last,
  .woocommerce ul.products.columns-4 li.first,
  .woocommerce ul.products.columns-4 li.last,
  .woocommerce ul.products.columns-3 li.first,
  .woocommerce ul.products.columns-3 li.last,
  .woocommerce ul.products.columns-2 li.first,
  .woocommerce ul.products.columns-2 li.last,
  .woocommerce ul.products.columns-1 li.first,
  .woocommerce ul.products.columns-1 li.last {
    clear: none;
  }
  .woocommerce ul.products.columns-6 li.product,
  .woocommerce ul.products.columns-5 li.product,
  .woocommerce ul.products.columns-4 li.product,
  .woocommerce ul.products.columns-3 li.product,
  .woocommerce ul.products.columns-2 li.product {
    width: 50%;
  }
  .woocommerce ul.products.columns-1 li.product {
    width: 100%;
  }

  .woocommerce-cart ul.products,
  .woocommerce.single-product ul.products {
    display: block;
  }
  .woocommerce-cart ul.products li.product,
  .woocommerce.single-product ul.products li.product {
    width: 50%;
  }
}
@media (max-width: 767px) and (-ms-high-contrast: active), (max-width: 767px) and (-ms-high-contrast: none) {
  .woocommerce ul.products.columns-6 li.product,
  .woocommerce ul.products.columns-5 li.product,
  .woocommerce ul.products.columns-4 li.product,
  .woocommerce ul.products.columns-3 li.product,
  .woocommerce ul.products.columns-2 li.product,
  .woocommerce ul.products.columns-1 li.product {
    width: 100%;
  }

  .woocommerce-cart ul.products,
  .woocommerce.single-product ul.products {
    display: block;
  }
  .woocommerce-cart ul.products li.product,
  .woocommerce.single-product ul.products li.product {
    width: 100%;
  }
}
/*--------------------------------------------------------------
## Cart product
--------------------------------------------------------------*/
.card-product {
  vertical-align: top;
  margin-top: 30px;
}
.card-product .btn-simple.btn-just-icon {
  padding: 0;
}
.card-product .footer {
  display: table;
  margin-top: 5px;
  width: 100%;
}
.card-product .footer .price {
  display: table-cell !important;
  vertical-align: top;
  text-align: right;
}
.card-product .footer .price h4 {
  color: #3C4858;
  margin-bottom: 0;
}
.card-product .footer .stats {
  display: table-cell !important;
  padding-right: 10px;
  vertical-align: bottom;
  float: none;
  text-align: left;
}
.card-product .footer .stats a {
  margin: 10px 0 !important;
}
.card-product .footer .stats a.button,
.card-product .footer .stats a.button:hover {
  box-shadow: none !important;
  color: inherit !important;
}
.card-product .footer .stats i {
  top: 0;
  margin-bottom: 2px;
}
.card-product .card-description ul {
  list-style: none outside;
  padding: 0;
  margin-bottom: 10px;
}
.card-product .card-title,
.card-product .category,
.card-product .card-description {
  text-align: center;
}

.product-category.product h2.woocommerce-loop-category__title {
  font-size: 18px !important;
}

/* Raise card-plain on shop loop items
 * without adding box-shadow
 */
.card-product.card-plain .card-image {
  margin-top: -30px;
}

/**
 * Card image hover style
 */
.card-product .card-image a:hover {
  opacity: 1 !important;
}
.card-product.swap-images:hover .card-image {
  transform: none;
  box-shadow: 0 5px 15px -8px rgba(0, 0, 0, 0.24), 0 8px 10px -5px rgba(0, 0, 0, 0.2), 0 10px 10px -5px rgba(0, 0, 0, 0.2);
}
.card-product.card-plain .card-image {
  box-shadow: none;
  padding: 5px;
}
.card-product.card-plain .card-image > .onsale {
  margin: 0;
}
.card-product.card-plain.swap-images:hover .card-image {
  box-shadow: none;
  padding: 5px;
}
.card-product.card-plain.pop-and-glow:hover .card-image {
  box-shadow: none;
}
.card-product.card-plain.pop-and-glow:hover .card-image img {
  -webkit-box-shadow: 0 15px 35px -15px rgba(0, 0, 0, 0.5), 0 5px 25px 0 rgba(0, 0, 0, 0.12), 0 10px 10px -5px rgba(0, 0, 0, 0.2);
  box-shadow: 0 15px 35px -15px rgba(0, 0, 0, 0.5), 0 5px 25px 0 rgba(0, 0, 0, 0.12), 0 10px 10px -5px rgba(0, 0, 0, 0.2);
}
.card-product .card-image, .card-product .card-image img {
  transition: all 0.3s;
}
.card-product.pop-and-glow .card-image {
  overflow: visible;
}
.card-product.pop-and-glow:hover .card-image {
  -webkit-transform: translate(0, -10px);
  -ms-transform: translate(0, -10px);
  transform: translate(0, -10px);
  -webkit-box-shadow: 0 15px 35px -15px rgba(0, 0, 0, 0.5), 0 5px 25px 0 rgba(0, 0, 0, 0.12), 0 10px 10px -5px rgba(0, 0, 0, 0.2);
  box-shadow: 0 15px 35px -15px rgba(0, 0, 0, 0.5), 0 5px 25px 0 rgba(0, 0, 0, 0.12), 0 10px 10px -5px rgba(0, 0, 0, 0.2);
}
.card-product.zoom .card-image a {
  display: inline-flex;
  overflow: hidden;
}
.card-product.zoom:hover .card-image a img {
  transform: scale(1.1);
}
.card-product.swap-images .card-image a img:nth-of-type(2) {
  display: none;
}
.card-product.swap-images:hover .card-image {
  transform: none;
}
.card-product.swap-images:hover .card-image a img:nth-of-type(2) {
  display: inline-flex;
}
.card-product.swap-images:hover .card-image a img:first-child {
  display: none;
}
.card-product.blur:hover .card-image a {
  filter: blur(2px);
}
.card-product.fadein .card-image a {
  opacity: .7;
}
.card-product.fadein:hover .card-image a {
  opacity: 1;
}
.card-product.fadeout:hover .card-image img {
  opacity: .7;
}
.card-product.glow:hover .card-image img {
  filter: brightness(1.1);
}
.card-product.colorize .card-image img {
  filter: grayscale(100%);
}
.card-product.colorize:hover > .card-image img {
  filter: grayscale(0%);
}
.card-product.grayscale:hover .card-image img {
  filter: grayscale(100%);
}

/*--------------------------------------------------------------
## YITH Magnifier
--------------------------------------------------------------*/
li.yith_magnifier_thumbnail {
  display: block;
  position: relative;
  padding: 0 10px;
}
li.yith_magnifier_thumbnail a {
  margin: 25px auto;
}
li.yith_magnifier_thumbnail a img {
  border-radius: 6px;
}

.yith_magnifier_zoom_magnifier {
  border: none !important;
}

#yith-quick-view-content div.entry-summary {
  padding: 15px 40px 15px 15px;
}
#yith-quick-view-content .product_meta {
  margin-top: 20px;
}

.woocommerce .card-product a.button.yith-wcqv-button {
  margin-bottom: 30px;
}
