.cpw-code {
	display: block;
	padding: 10px;
}
.cpw-clipboard {
	display: block;
	font-size: .9em;
	padding: 10px 0;
	text-align: right;
}
.cpw-clipboard:hover {
	cursor: copy;
}
.cpw-information {
	height: 8em;
	width: 100%;
}
