.hestia-mm-description {
  display: none;
  opacity: .75;
}

.hestia-mega-menu .hestia-mm-description {
  display: block;
}

.navbar .hestia-mega-menu > .dropdown-menu {
  margin: auto;
  right: 0;
  left: 0;
}

@media (min-width: 769px) {
  .navbar .hestia-mega-menu > .dropdown-menu {
    width: 750px;
    right: 50% !important;
    transform: translateX(50%);
  }

  /* one item */
  .hestia-mega-menu > .dropdown-menu .hestia-mm-col:first-child:nth-last-child(1) {
    /* -or- li:only-child { */
    width: 100%;
  }

  /* two items */
  .hestia-mega-menu > .dropdown-menu .hestia-mm-col:first-child:nth-last-child(2),
  .hestia-mega-menu > .dropdown-menu .hestia-mm-col:first-child:nth-last-child(2) ~ li {
    width: 50%;
  }

  /* three items */
  .hestia-mega-menu > .dropdown-menu .hestia-mm-col:first-child:nth-last-child(3),
  .hestia-mega-menu > .dropdown-menu .hestia-mm-col:first-child:nth-last-child(3) ~ li {
    width: 33.3333%;
  }

  /* four items */
  .hestia-mega-menu > .dropdown-menu .hestia-mm-col:first-child:nth-last-child(4),
  .hestia-mega-menu > .dropdown-menu .hestia-mm-col:first-child:nth-last-child(4) ~ li {
    width: 25%;
  }

  /* five items */
  .hestia-mega-menu > .dropdown-menu .hestia-mm-col:first-child:nth-last-child(5),
  .hestia-mega-menu > .dropdown-menu .hestia-mm-col:first-child:nth-last-child(5) ~ li {
    width: 20%;
  }

  /* six items */
  .hestia-mega-menu > .dropdown-menu .hestia-mm-col:first-child:nth-last-child(5),
  .hestia-mega-menu > .dropdown-menu .hestia-mm-col:first-child:nth-last-child(5) ~ li {
    width: 16.66666666666667%;
  }
}
@media (min-width: 992px) {
  .navbar .hestia-mega-menu > .dropdown-menu {
    width: 970px;
  }
}
@media (min-width: 1200px) {
  .navbar .hestia-mega-menu > .dropdown-menu {
    width: 1170px;
  }
}
.navbar .navbar-nav > li.hestia-mega-menu {
  position: static;
}

.navbar .hestia-mega-menu > .dropdown-menu > li > a {
  margin: 0;
}

.hestia-mega-menu > .dropdown-menu {
  padding: 5px;
  color: #333 !important;
  left: auto;
  width: 100%;
  right: 0;
  display: table;
  top: inherit;
}
.hestia-mega-menu > .dropdown-menu .divider {
  height: 1px;
  margin: 9px auto;
  width: 75%;
}

.hestia-mega-menu:hover .hestia-mm-col > .dropdown-menu,
.hestia-mega-menu.open .hestia-mm-col > .dropdown-menu {
  visibility: visible;
}

.hestia-mega-menu .hestia-mm-col {
  text-align: center;
  vertical-align: top;
  display: table-cell;
  position: relative;
  padding: 5px;
}
.hestia-mega-menu .hestia-mm-col > a {
  display: none;
}

.hestia-mega-menu .hestia-mm-col > .dropdown-menu {
  float: none;
  background: none;
  box-shadow: none;
  opacity: 1;
  display: inline-block !important;
  position: static;
  right: inherit;
}

.navbar .hestia-mm-heading {
  margin: 10px 0 10px 5px;
}

.navbar .hestia-mm-heading > span {
  text-transform: uppercase;
  padding: 7px 10px 5px 10px;
  margin: 0 5px;
}

.navbar .hestia-mm-heading > .mm-heading-wrapper a:hover {
  text-decoration: underline;
}

.mm-heading-wrapper a {
  color: #333;
  padding: 0;
}

.hestia-mm-description {
  color: #333;
  padding: 7px 10px 5px 10px;
  margin: 0 5px;
}

.hestia_right .dropdown-menu > .hestia-mega-menu > .dropdown-menu {
  display: block;
  width: auto;
  right: 100%;
}

.hestia_left .dropdown-menu > .hestia-mega-menu > .dropdown-menu {
  display: block;
  width: auto;
  left: 100%;
  right: auto;
  top: 0;
}

@media (max-width: 768px) {
  .navbar .hestia-mm-col.dropdown-submenu:hover > .dropdown-menu {
    display: inline-block !important;
  }

  .navbar .navbar-nav .dropdown .dropdown-menu li li .mm-heading-wrapper a {
    padding: 0;
  }

  .hestia-mega-menu > .dropdown-menu {
    display: none;
  }

  .hestia-mega-menu > .dropdown-menu .divider {
    width: 100%;
    margin: 15px auto;
  }

  .navbar .navbar-nav .dropdown li.hestia-mm-heading {
    padding: 15px 0;
  }
}
